// Code generated by go generate; DO NOT EDIT.
// This file was generated using data from https://spdx.org/licenses/licenses.json
package spdxlicense

const Version = "3.28.0"

var licenseIDs = map[string]string{
	"0bsd":                                  "0BSD",
	"3.0.0dslicer1.0":                       "3D-Slicer-1.0",
	"3.0dslicer1.0":                         "3D-Slicer-1.0",
	"3dslicer1.0":                           "3D-Slicer-1.0",
	"aal":                                   "AAL",
	"abstyles":                              "Abstyles",
	"adacoredoc":                            "AdaCore-doc",
	"adobe2006":                             "Adobe-2006",
	"adobe2006.0":                           "Adobe-2006",
	"adobe2006.0.0":                         "Adobe-2006",
	"adobedisplaypostscript":                "Adobe-Display-PostScript",
	"adobeglyph":                            "Adobe-Glyph",
	"adobeutopia":                           "Adobe-Utopia",
	"adsl":                                  "ADSL",
	"advancedcrypticsdictionary":            "Advanced-Cryptics-Dictionary",
	"afl1":                                  "AFL-1.1",
	"afl1.1":                                "AFL-1.1",
	"afl1.1.0":                              "AFL-1.1",
	"afl1.2":                                "AFL-1.2",
	"afl1.2.0":                              "AFL-1.2",
	"afl2":                                  "AFL-2.0",
	"afl2.0":                                "AFL-2.0",
	"afl2.0.0":                              "AFL-2.0",
	"afl2.1":                                "AFL-2.1",
	"afl2.1.0":                              "AFL-2.1",
	"afl3":                                  "AFL-3.0",
	"afl3.0":                                "AFL-3.0",
	"afl3.0.0":                              "AFL-3.0",
	"afmparse":                              "Afmparse",
	"agpl1":                                 "AGPL-1.0-only",
	"agpl1+":                                "AGPL-1.0-or-later",
	"agpl1.0":                               "AGPL-1.0-only",
	"agpl1.0+":                              "AGPL-1.0-or-later",
	"agpl1.0.0":                             "AGPL-1.0-only",
	"agpl1.0.0+":                            "AGPL-1.0-or-later",
	"agpl1.0.0only":                         "AGPL-1.0-only",
	"agpl1.0.0orlater":                      "AGPL-1.0-or-later",
	"agpl1.0only":                           "AGPL-1.0-only",
	"agpl1.0orlater":                        "AGPL-1.0-or-later",
	"agpl1only":                             "AGPL-1.0-only",
	"agpl1orlater":                          "AGPL-1.0-or-later",
	"agpl3":                                 "AGPL-3.0-only",
	"agpl3+":                                "AGPL-3.0-or-later",
	"agpl3.0":                               "AGPL-3.0-only",
	"agpl3.0+":                              "AGPL-3.0-or-later",
	"agpl3.0.0":                             "AGPL-3.0-only",
	"agpl3.0.0+":                            "AGPL-3.0-or-later",
	"agpl3.0.0only":                         "AGPL-3.0-only",
	"agpl3.0.0orlater":                      "AGPL-3.0-or-later",
	"agpl3.0only":                           "AGPL-3.0-only",
	"agpl3.0orlater":                        "AGPL-3.0-or-later",
	"agpl3only":                             "AGPL-3.0-only",
	"agpl3orlater":                          "AGPL-3.0-or-later",
	"aladdin":                               "Aladdin",
	"alglibdocumentation":                   "ALGLIB-Documentation",
	"amdnewlib":                             "AMD-newlib",
	"amdplpa":                               "AMDPLPA",
	"aml":                                   "AML",
	"amlglslang":                            "AML-glslang",
	"ampas":                                 "AMPAS",
	"antlrpd":                               "ANTLR-PD",
	"antlrpdfallback":                       "ANTLR-PD-fallback",
	"anyosi":                                "any-OSI",
	"anyosiperlmodules":                     "any-OSI-perl-modules",
	"apache1":                               "Apache-1.0",
	"apache1.0":                             "Apache-1.0",
	"apache1.0.0":                           "Apache-1.0",
	"apache1.1":                             "Apache-1.1",
	"apache1.1.0":                           "Apache-1.1",
	"apache2":                               "Apache-2.0",
	"apache2.0":                             "Apache-2.0",
	"apache2.0.0":                           "Apache-2.0",
	"apafml":                                "APAFML",
	"apl1":                                  "APL-1.0",
	"apl1.0":                                "APL-1.0",
	"apl1.0.0":                              "APL-1.0",
	"apps2.0.0p":                            "App-s2p",
	"apps2.0p":                              "App-s2p",
	"apps2p":                                "App-s2p",
	"apsl1":                                 "APSL-1.0",
	"apsl1.0":                               "APSL-1.0",
	"apsl1.0.0":                             "APSL-1.0",
	"apsl1.1":                               "APSL-1.1",
	"apsl1.1.0":                             "APSL-1.1",
	"apsl1.2":                               "APSL-1.2",
	"apsl1.2.0":                             "APSL-1.2",
	"apsl2":                                 "APSL-2.0",
	"apsl2.0":                               "APSL-2.0",
	"apsl2.0.0":                             "APSL-2.0",
	"arphic1999":                            "Arphic-1999",
	"arphic1999.0":                          "Arphic-1999",
	"arphic1999.0.0":                        "Arphic-1999",
	"artistic1":                             "Artistic-1.0",
	"artistic1.0":                           "Artistic-1.0",
	"artistic1.0.0":                         "Artistic-1.0",
	"artistic1.0.0cl8":                      "Artistic-1.0-cl8",
	"artistic1.0.0perl":                     "Artistic-1.0-Perl",
	"artistic1.0cl8":                        "Artistic-1.0-cl8",
	"artistic1.0perl":                       "Artistic-1.0-Perl",
	"artistic1cl8":                          "Artistic-1.0-cl8",
	"artistic1perl":                         "Artistic-1.0-Perl",
	"artistic2":                             "Artistic-2.0",
	"artistic2.0":                           "Artistic-2.0",
	"artistic2.0.0":                         "Artistic-2.0",
	"artisticdist":                          "Artistic-dist",
	"aspellru":                              "Aspell-RU",
	"aswfdigitalassets1":                    "ASWF-Digital-Assets-1.0",
	"aswfdigitalassets1.0":                  "ASWF-Digital-Assets-1.0",
	"aswfdigitalassets1.0.0":                "ASWF-Digital-Assets-1.0",
	"aswfdigitalassets1.1":                  "ASWF-Digital-Assets-1.1",
	"aswfdigitalassets1.1.0":                "ASWF-Digital-Assets-1.1",
	"baekmuk":                               "Baekmuk",
	"bahyph":                                "Bahyph",
	"barr":                                  "Barr",
	"bcryptsolardesigner":                   "bcrypt-Solar-Designer",
	"beerware":                              "Beerware",
	"bitstreamcharter":                      "Bitstream-Charter",
	"bitstreamvera":                         "Bitstream-Vera",
	"bittorrent1":                           "BitTorrent-1.0",
	"bittorrent1.0":                         "BitTorrent-1.0",
	"bittorrent1.0.0":                       "BitTorrent-1.0",
	"bittorrent1.1":                         "BitTorrent-1.1",
	"bittorrent1.1.0":                       "BitTorrent-1.1",
	"blessing":                              "blessing",
	"blueoak1":                              "BlueOak-1.0.0",
	"blueoak1.0":                            "BlueOak-1.0.0",
	"blueoak1.0.0":                          "BlueOak-1.0.0",
	"boehmgc":                               "Boehm-GC",
	"boehmgcwithoutfee":                     "Boehm-GC-without-fee",
	"bola1":                                 "BOLA-1.1",
	"bola1.1":                               "BOLA-1.1",
	"bola1.1.0":                             "BOLA-1.1",
	"borceux":                               "Borceux",
	"briangladman2.0.0clause":               "Brian-Gladman-2-Clause",
	"briangladman2.0clause":                 "Brian-Gladman-2-Clause",
	"briangladman2clause":                   "Brian-Gladman-2-Clause",
	"briangladman3.0.0clause":               "Brian-Gladman-3-Clause",
	"briangladman3.0clause":                 "Brian-Gladman-3-Clause",
	"briangladman3clause":                   "Brian-Gladman-3-Clause",
	"bsd1.0.0clause":                        "BSD-1-Clause",
	"bsd1.0clause":                          "BSD-1-Clause",
	"bsd1clause":                            "BSD-1-Clause",
	"bsd2.0.0clause":                        "BSD-2-Clause",
	"bsd2.0.0clausedarwin":                  "BSD-2-Clause-Darwin",
	"bsd2.0.0clausefirstlines":              "BSD-2-Clause-first-lines",
	"bsd2.0.0clausefreebsd":                 "BSD-2-Clause-Views",
	"bsd2.0.0clausenetbsd":                  "BSD-2-Clause",
	"bsd2.0.0clausepatent":                  "BSD-2-Clause-Patent",
	"bsd2.0.0clausepkgconfdisclaimer":       "BSD-2-Clause-pkgconf-disclaimer",
	"bsd2.0.0clauseviews":                   "BSD-2-Clause-Views",
	"bsd2.0clause":                          "BSD-2-Clause",
	"bsd2.0clausedarwin":                    "BSD-2-Clause-Darwin",
	"bsd2.0clausefirstlines":                "BSD-2-Clause-first-lines",
	"bsd2.0clausefreebsd":                   "BSD-2-Clause-Views",
	"bsd2.0clausenetbsd":                    "BSD-2-Clause",
	"bsd2.0clausepatent":                    "BSD-2-Clause-Patent",
	"bsd2.0clausepkgconfdisclaimer":         "BSD-2-Clause-pkgconf-disclaimer",
	"bsd2.0clauseviews":                     "BSD-2-Clause-Views",
	"bsd2clause":                            "BSD-2-Clause",
	"bsd2clausedarwin":                      "BSD-2-Clause-Darwin",
	"bsd2clausefirstlines":                  "BSD-2-Clause-first-lines",
	"bsd2clausefreebsd":                     "BSD-2-Clause-Views",
	"bsd2clausenetbsd":                      "BSD-2-Clause",
	"bsd2clausepatent":                      "BSD-2-Clause-Patent",
	"bsd2clausepkgconfdisclaimer":           "BSD-2-Clause-pkgconf-disclaimer",
	"bsd2clauseviews":                       "BSD-2-Clause-Views",
	"bsd3.0.0clause":                        "BSD-3-Clause",
	"bsd3.0.0clauseacpica":                  "BSD-3-Clause-acpica",
	"bsd3.0.0clauseattribution":             "BSD-3-Clause-Attribution",
	"bsd3.0.0clauseclear":                   "BSD-3-Clause-Clear",
	"bsd3.0.0clauseflex":                    "BSD-3-Clause-flex",
	"bsd3.0.0clausehp":                      "BSD-3-Clause-HP",
	"bsd3.0.0clauselbnl":                    "BSD-3-Clause-LBNL",
	"bsd3.0.0clausemodification":            "BSD-3-Clause-Modification",
	"bsd3.0.0clausenomilitarylicense":       "BSD-3-Clause-No-Military-License",
	"bsd3.0.0clausenonuclearlicense":        "BSD-3-Clause-No-Nuclear-License",
	"bsd3.0.0clausenonuclearlicense2014":    "BSD-3-Clause-No-Nuclear-License-2014",
	"bsd3.0.0clausenonuclearwarranty":       "BSD-3-Clause-No-Nuclear-Warranty",
	"bsd3.0.0clauseopenmpi":                 "BSD-3-Clause-Open-MPI",
	"bsd3.0.0clausesun":                     "BSD-3-Clause-Sun",
	"bsd3.0.0clausetso":                     "BSD-3-Clause-Tso",
	"bsd3.0clause":                          "BSD-3-Clause",
	"bsd3.0clauseacpica":                    "BSD-3-Clause-acpica",
	"bsd3.0clauseattribution":               "BSD-3-Clause-Attribution",
	"bsd3.0clauseclear":                     "BSD-3-Clause-Clear",
	"bsd3.0clauseflex":                      "BSD-3-Clause-flex",
	"bsd3.0clausehp":                        "BSD-3-Clause-HP",
	"bsd3.0clauselbnl":                      "BSD-3-Clause-LBNL",
	"bsd3.0clausemodification":              "BSD-3-Clause-Modification",
	"bsd3.0clausenomilitarylicense":         "BSD-3-Clause-No-Military-License",
	"bsd3.0clausenonuclearlicense":          "BSD-3-Clause-No-Nuclear-License",
	"bsd3.0clausenonuclearlicense2014":      "BSD-3-Clause-No-Nuclear-License-2014",
	"bsd3.0clausenonuclearwarranty":         "BSD-3-Clause-No-Nuclear-Warranty",
	"bsd3.0clauseopenmpi":                   "BSD-3-Clause-Open-MPI",
	"bsd3.0clausesun":                       "BSD-3-Clause-Sun",
	"bsd3.0clausetso":                       "BSD-3-Clause-Tso",
	"bsd3clause":                            "BSD-3-Clause",
	"bsd3clauseacpica":                      "BSD-3-Clause-acpica",
	"bsd3clauseattribution":                 "BSD-3-Clause-Attribution",
	"bsd3clauseclear":                       "BSD-3-Clause-Clear",
	"bsd3clauseflex":                        "BSD-3-Clause-flex",
	"bsd3clausehp":                          "BSD-3-Clause-HP",
	"bsd3clauselbnl":                        "BSD-3-Clause-LBNL",
	"bsd3clausemodification":                "BSD-3-Clause-Modification",
	"bsd3clausenomilitarylicense":           "BSD-3-Clause-No-Military-License",
	"bsd3clausenonuclearlicense":            "BSD-3-Clause-No-Nuclear-License",
	"bsd3clausenonuclearlicense2014":        "BSD-3-Clause-No-Nuclear-License-2014",
	"bsd3clausenonuclearwarranty":           "BSD-3-Clause-No-Nuclear-Warranty",
	"bsd3clauseopenmpi":                     "BSD-3-Clause-Open-MPI",
	"bsd3clausesun":                         "BSD-3-Clause-Sun",
	"bsd3clausetso":                         "BSD-3-Clause-Tso",
	"bsd4.0.0clause":                        "BSD-4-Clause",
	"bsd4.0.0clauseshortened":               "BSD-4-Clause-Shortened",
	"bsd4.0.0clauseuc":                      "BSD-4-Clause-UC",
	"bsd4.0clause":                          "BSD-4-Clause",
	"bsd4.0clauseshortened":                 "BSD-4-Clause-Shortened",
	"bsd4.0clauseuc":                        "BSD-4-Clause-UC",
	"bsd4.3.0reno":                          "BSD-4.3RENO",
	"bsd4.3.0tahoe":                         "BSD-4.3TAHOE",
	"bsd4.3reno":                            "BSD-4.3RENO",
	"bsd4.3tahoe":                           "BSD-4.3TAHOE",
	"bsd4clause":                            "BSD-4-Clause",
	"bsd4clauseshortened":                   "BSD-4-Clause-Shortened",
	"bsd4clauseuc":                          "BSD-4-Clause-UC",
	"bsd4reno":                              "BSD-4.3RENO",
	"bsd4tahoe":                             "BSD-4.3TAHOE",
	"bsdadvertisingacknowledgement":         "BSD-Advertising-Acknowledgement",
	"bsdattributionhpnddisclaimer":          "BSD-Attribution-HPND-disclaimer",
	"bsdinfernonettverk":                    "BSD-Inferno-Nettverk",
	"bsdmarkmodifications":                  "BSD-Mark-Modifications",
	"bsdprotection":                         "BSD-Protection",
	"bsdsourcebeginningfile":                "BSD-Source-beginning-file",
	"bsdsourcecode":                         "BSD-Source-Code",
	"bsdsystemics":                          "BSD-Systemics",
	"bsdsystemicsw3.0.0works":               "BSD-Systemics-W3Works",
	"bsdsystemicsw3.0works":                 "BSD-Systemics-W3Works",
	"bsdsystemicsw3works":                   "BSD-Systemics-W3Works",
	"bsl1":                                  "BSL-1.0",
	"bsl1.0":                                "BSL-1.0",
	"bsl1.0.0":                              "BSL-1.0",
	"buddy":                                 "Buddy",
	"busl1":                                 "BUSL-1.1",
	"busl1.1":                               "BUSL-1.1",
	"busl1.1.0":                             "BUSL-1.1",
	"bzip21":                                "bzip2-1.0.6",
	"bzip21.0":                              "bzip2-1.0.6",
	"bzip21.0.5":                            "bzip2-1.0.6",
	"bzip21.0.6":                            "bzip2-1.0.6",
	"cal1":                                  "CAL-1.0",
	"cal1.0":                                "CAL-1.0",
	"cal1.0.0":                              "CAL-1.0",
	"cal1.0.0combinedworkexception":         "CAL-1.0-Combined-Work-Exception",
	"cal1.0combinedworkexception":           "CAL-1.0-Combined-Work-Exception",
	"cal1combinedworkexception":             "CAL-1.0-Combined-Work-Exception",
	"caldera":                               "Caldera",
	"calderanopreamble":                     "Caldera-no-preamble",
	"capectou":                              "CAPEC-tou",
	"catharon":                              "Catharon",
	"catosl1":                               "CATOSL-1.1",
	"catosl1.1":                             "CATOSL-1.1",
	"catosl1.1.0":                           "CATOSL-1.1",
	"cc01":                                  "CC0-1.0",
	"cc01.0":                                "CC0-1.0",
	"cc01.0.0":                              "CC0-1.0",
	"ccby1":                                 "CC-BY-1.0",
	"ccby1.0":                               "CC-BY-1.0",
	"ccby1.0.0":                             "CC-BY-1.0",
	"ccby2":                                 "CC-BY-2.0",
	"ccby2.0":                               "CC-BY-2.0",
	"ccby2.0.0":                             "CC-BY-2.0",
	"ccby2.5":                               "CC-BY-2.5",
	"ccby2.5.0":                             "CC-BY-2.5",
	"ccby2.5.0au":                           "CC-BY-2.5-AU",
	"ccby2.5au":                             "CC-BY-2.5-AU",
	"ccby2au":                               "CC-BY-2.5-AU",
	"ccby3":                                 "CC-BY-3.0",
	"ccby3.0":                               "CC-BY-3.0",
	"ccby3.0.0":                             "CC-BY-3.0",
	"ccby3.0.0at":                           "CC-BY-3.0-AT",
	"ccby3.0.0au":                           "CC-BY-3.0-AU",
	"ccby3.0.0de":                           "CC-BY-3.0-DE",
	"ccby3.0.0igo":                          "CC-BY-3.0-IGO",
	"ccby3.0.0nl":                           "CC-BY-3.0-NL",
	"ccby3.0.0us":                           "CC-BY-3.0-US",
	"ccby3.0at":                             "CC-BY-3.0-AT",
	"ccby3.0au":                             "CC-BY-3.0-AU",
	"ccby3.0de":                             "CC-BY-3.0-DE",
	"ccby3.0igo":                            "CC-BY-3.0-IGO",
	"ccby3.0nl":                             "CC-BY-3.0-NL",
	"ccby3.0us":                             "CC-BY-3.0-US",
	"ccby3at":                               "CC-BY-3.0-AT",
	"ccby3au":                               "CC-BY-3.0-AU",
	"ccby3de":                               "CC-BY-3.0-DE",
	"ccby3igo":                              "CC-BY-3.0-IGO",
	"ccby3nl":                               "CC-BY-3.0-NL",
	"ccby3us":                               "CC-BY-3.0-US",
	"ccby4":                                 "CC-BY-4.0",
	"ccby4.0":                               "CC-BY-4.0",
	"ccby4.0.0":                             "CC-BY-4.0",
	"ccbync1":                               "CC-BY-NC-1.0",
	"ccbync1.0":                             "CC-BY-NC-1.0",
	"ccbync1.0.0":                           "CC-BY-NC-1.0",
	"ccbync2":                               "CC-BY-NC-2.0",
	"ccbync2.0":                             "CC-BY-NC-2.0",
	"ccbync2.0.0":                           "CC-BY-NC-2.0",
	"ccbync2.5":                             "CC-BY-NC-2.5",
	"ccbync2.5.0":                           "CC-BY-NC-2.5",
	"ccbync3":                               "CC-BY-NC-3.0",
	"ccbync3.0":                             "CC-BY-NC-3.0",
	"ccbync3.0.0":                           "CC-BY-NC-3.0",
	"ccbync3.0.0de":                         "CC-BY-NC-3.0-DE",
	"ccbync3.0de":                           "CC-BY-NC-3.0-DE",
	"ccbync3de":                             "CC-BY-NC-3.0-DE",
	"ccbync4":                               "CC-BY-NC-4.0",
	"ccbync4.0":                             "CC-BY-NC-4.0",
	"ccbync4.0.0":                           "CC-BY-NC-4.0",
	"ccbyncnd1":                             "CC-BY-NC-ND-1.0",
	"ccbyncnd1.0":                           "CC-BY-NC-ND-1.0",
	"ccbyncnd1.0.0":                         "CC-BY-NC-ND-1.0",
	"ccbyncnd2":                             "CC-BY-NC-ND-2.0",
	"ccbyncnd2.0":                           "CC-BY-NC-ND-2.0",
	"ccbyncnd2.0.0":                         "CC-BY-NC-ND-2.0",
	"ccbyncnd2.5":                           "CC-BY-NC-ND-2.5",
	"ccbyncnd2.5.0":                         "CC-BY-NC-ND-2.5",
	"ccbyncnd3":                             "CC-BY-NC-ND-3.0",
	"ccbyncnd3.0":                           "CC-BY-NC-ND-3.0",
	"ccbyncnd3.0.0":                         "CC-BY-NC-ND-3.0",
	"ccbyncnd3.0.0de":                       "CC-BY-NC-ND-3.0-DE",
	"ccbyncnd3.0.0igo":                      "CC-BY-NC-ND-3.0-IGO",
	"ccbyncnd3.0de":                         "CC-BY-NC-ND-3.0-DE",
	"ccbyncnd3.0igo":                        "CC-BY-NC-ND-3.0-IGO",
	"ccbyncnd3de":                           "CC-BY-NC-ND-3.0-DE",
	"ccbyncnd3igo":                          "CC-BY-NC-ND-3.0-IGO",
	"ccbyncnd4":                             "CC-BY-NC-ND-4.0",
	"ccbyncnd4.0":                           "CC-BY-NC-ND-4.0",
	"ccbyncnd4.0.0":                         "CC-BY-NC-ND-4.0",
	"ccbyncsa1":                             "CC-BY-NC-SA-1.0",
	"ccbyncsa1.0":                           "CC-BY-NC-SA-1.0",
	"ccbyncsa1.0.0":                         "CC-BY-NC-SA-1.0",
	"ccbyncsa2":                             "CC-BY-NC-SA-2.0",
	"ccbyncsa2.0":                           "CC-BY-NC-SA-2.0",
	"ccbyncsa2.0.0":                         "CC-BY-NC-SA-2.0",
	"ccbyncsa2.0.0de":                       "CC-BY-NC-SA-2.0-DE",
	"ccbyncsa2.0.0fr":                       "CC-BY-NC-SA-2.0-FR",
	"ccbyncsa2.0.0uk":                       "CC-BY-NC-SA-2.0-UK",
	"ccbyncsa2.0de":                         "CC-BY-NC-SA-2.0-DE",
	"ccbyncsa2.0fr":                         "CC-BY-NC-SA-2.0-FR",
	"ccbyncsa2.0uk":                         "CC-BY-NC-SA-2.0-UK",
	"ccbyncsa2.5":                           "CC-BY-NC-SA-2.5",
	"ccbyncsa2.5.0":                         "CC-BY-NC-SA-2.5",
	"ccbyncsa2de":                           "CC-BY-NC-SA-2.0-DE",
	"ccbyncsa2fr":                           "CC-BY-NC-SA-2.0-FR",
	"ccbyncsa2uk":                           "CC-BY-NC-SA-2.0-UK",
	"ccbyncsa3":                             "CC-BY-NC-SA-3.0",
	"ccbyncsa3.0":                           "CC-BY-NC-SA-3.0",
	"ccbyncsa3.0.0":                         "CC-BY-NC-SA-3.0",
	"ccbyncsa3.0.0de":                       "CC-BY-NC-SA-3.0-DE",
	"ccbyncsa3.0.0igo":                      "CC-BY-NC-SA-3.0-IGO",
	"ccbyncsa3.0de":                         "CC-BY-NC-SA-3.0-DE",
	"ccbyncsa3.0igo":                        "CC-BY-NC-SA-3.0-IGO",
	"ccbyncsa3de":                           "CC-BY-NC-SA-3.0-DE",
	"ccbyncsa3igo":                          "CC-BY-NC-SA-3.0-IGO",
	"ccbyncsa4":                             "CC-BY-NC-SA-4.0",
	"ccbyncsa4.0":                           "CC-BY-NC-SA-4.0",
	"ccbyncsa4.0.0":                         "CC-BY-NC-SA-4.0",
	"ccbynd1":                               "CC-BY-ND-1.0",
	"ccbynd1.0":                             "CC-BY-ND-1.0",
	"ccbynd1.0.0":                           "CC-BY-ND-1.0",
	"ccbynd2":                               "CC-BY-ND-2.0",
	"ccbynd2.0":                             "CC-BY-ND-2.0",
	"ccbynd2.0.0":                           "CC-BY-ND-2.0",
	"ccbynd2.5":                             "CC-BY-ND-2.5",
	"ccbynd2.5.0":                           "CC-BY-ND-2.5",
	"ccbynd3":                               "CC-BY-ND-3.0",
	"ccbynd3.0":                             "CC-BY-ND-3.0",
	"ccbynd3.0.0":                           "CC-BY-ND-3.0",
	"ccbynd3.0.0de":                         "CC-BY-ND-3.0-DE",
	"ccbynd3.0de":                           "CC-BY-ND-3.0-DE",
	"ccbynd3de":                             "CC-BY-ND-3.0-DE",
	"ccbynd4":                               "CC-BY-ND-4.0",
	"ccbynd4.0":                             "CC-BY-ND-4.0",
	"ccbynd4.0.0":                           "CC-BY-ND-4.0",
	"ccbysa1":                               "CC-BY-SA-1.0",
	"ccbysa1.0":                             "CC-BY-SA-1.0",
	"ccbysa1.0.0":                           "CC-BY-SA-1.0",
	"ccbysa2":                               "CC-BY-SA-2.0",
	"ccbysa2.0":                             "CC-BY-SA-2.0",
	"ccbysa2.0.0":                           "CC-BY-SA-2.0",
	"ccbysa2.0.0uk":                         "CC-BY-SA-2.0-UK",
	"ccbysa2.0uk":                           "CC-BY-SA-2.0-UK",
	"ccbysa2.1.0jp":                         "CC-BY-SA-2.1-JP",
	"ccbysa2.1jp":                           "CC-BY-SA-2.1-JP",
	"ccbysa2.5":                             "CC-BY-SA-2.5",
	"ccbysa2.5.0":                           "CC-BY-SA-2.5",
	"ccbysa2jp":                             "CC-BY-SA-2.1-JP",
	"ccbysa2uk":                             "CC-BY-SA-2.0-UK",
	"ccbysa3":                               "CC-BY-SA-3.0",
	"ccbysa3.0":                             "CC-BY-SA-3.0",
	"ccbysa3.0.0":                           "CC-BY-SA-3.0",
	"ccbysa3.0.0at":                         "CC-BY-SA-3.0-AT",
	"ccbysa3.0.0de":                         "CC-BY-SA-3.0-DE",
	"ccbysa3.0.0igo":                        "CC-BY-SA-3.0-IGO",
	"ccbysa3.0at":                           "CC-BY-SA-3.0-AT",
	"ccbysa3.0de":                           "CC-BY-SA-3.0-DE",
	"ccbysa3.0igo":                          "CC-BY-SA-3.0-IGO",
	"ccbysa3at":                             "CC-BY-SA-3.0-AT",
	"ccbysa3de":                             "CC-BY-SA-3.0-DE",
	"ccbysa3igo":                            "CC-BY-SA-3.0-IGO",
	"ccbysa4":                               "CC-BY-SA-4.0",
	"ccbysa4.0":                             "CC-BY-SA-4.0",
	"ccbysa4.0.0":                           "CC-BY-SA-4.0",
	"ccpddc":                                "CC-PDDC",
	"ccpdm1":                                "CC-PDM-1.0",
	"ccpdm1.0":                              "CC-PDM-1.0",
	"ccpdm1.0.0":                            "CC-PDM-1.0",
	"ccsa1":                                 "CC-SA-1.0",
	"ccsa1.0":                               "CC-SA-1.0",
	"ccsa1.0.0":                             "CC-SA-1.0",
	"cddl1":                                 "CDDL-1.0",
	"cddl1.0":                               "CDDL-1.0",
	"cddl1.0.0":                             "CDDL-1.0",
	"cddl1.1":                               "CDDL-1.1",
	"cddl1.1.0":                             "CDDL-1.1",
	"cdl1":                                  "CDL-1.0",
	"cdl1.0":                                "CDL-1.0",
	"cdl1.0.0":                              "CDL-1.0",
	"cdlapermissive1":                       "CDLA-Permissive-1.0",
	"cdlapermissive1.0":                     "CDLA-Permissive-1.0",
	"cdlapermissive1.0.0":                   "CDLA-Permissive-1.0",
	"cdlapermissive2":                       "CDLA-Permissive-2.0",
	"cdlapermissive2.0":                     "CDLA-Permissive-2.0",
	"cdlapermissive2.0.0":                   "CDLA-Permissive-2.0",
	"cdlasharing1":                          "CDLA-Sharing-1.0",
	"cdlasharing1.0":                        "CDLA-Sharing-1.0",
	"cdlasharing1.0.0":                      "CDLA-Sharing-1.0",
	"cecill1":                               "CECILL-1.0",
	"cecill1.0":                             "CECILL-1.0",
	"cecill1.0.0":                           "CECILL-1.0",
	"cecill1.1":                             "CECILL-1.1",
	"cecill1.1.0":                           "CECILL-1.1",
	"cecill2":                               "CECILL-2.0",
	"cecill2.0":                             "CECILL-2.0",
	"cecill2.0.0":                           "CECILL-2.0",
	"cecill2.1":                             "CECILL-2.1",
	"cecill2.1.0":                           "CECILL-2.1",
	"cecillb":                               "CECILL-B",
	"cecillc":                               "CECILL-C",
	"cernohl1":                              "CERN-OHL-1.1",
	"cernohl1.1":                            "CERN-OHL-1.1",
	"cernohl1.1.0":                          "CERN-OHL-1.1",
	"cernohl1.2":                            "CERN-OHL-1.2",
	"cernohl1.2.0":                          "CERN-OHL-1.2",
	"cernohlp2":                             "CERN-OHL-P-2.0",
	"cernohlp2.0":                           "CERN-OHL-P-2.0",
	"cernohlp2.0.0":                         "CERN-OHL-P-2.0",
	"cernohls2":                             "CERN-OHL-S-2.0",
	"cernohls2.0":                           "CERN-OHL-S-2.0",
	"cernohls2.0.0":                         "CERN-OHL-S-2.0",
	"cernohlw2":                             "CERN-OHL-W-2.0",
	"cernohlw2.0":                           "CERN-OHL-W-2.0",
	"cernohlw2.0.0":                         "CERN-OHL-W-2.0",
	"cfitsio":                               "CFITSIO",
	"checkcvs":                              "check-cvs",
	"checkmk":                               "checkmk",
	"clartistic":                            "ClArtistic",
	"clips":                                 "Clips",
	"cmumach":                               "CMU-Mach",
	"cmumachnodoc":                          "CMU-Mach-nodoc",
	"cnrijython":                            "CNRI-Jython",
	"cnripython":                            "CNRI-Python",
	"cnripythongplcompatible":               "CNRI-Python-GPL-Compatible",
	"coil1":                                 "COIL-1.0",
	"coil1.0":                               "COIL-1.0",
	"coil1.0.0":                             "COIL-1.0",
	"communityspec1":                        "Community-Spec-1.0",
	"communityspec1.0":                      "Community-Spec-1.0",
	"communityspec1.0.0":                    "Community-Spec-1.0",
	"condor1":                               "Condor-1.1",
	"condor1.1":                             "Condor-1.1",
	"condor1.1.0":                           "Condor-1.1",
	"copyleftnext0.3":                       "copyleft-next-0.3.0",
	"copyleftnext0.3.0":                     "copyleft-next-0.3.0",
	"copyleftnext0.3.1":                     "copyleft-next-0.3.1",
	"cornelllosslessjpeg":                   "Cornell-Lossless-JPEG",
	"cpal1":                                 "CPAL-1.0",
	"cpal1.0":                               "CPAL-1.0",
	"cpal1.0.0":                             "CPAL-1.0",
	"cpl1":                                  "CPL-1.0",
	"cpl1.0":                                "CPL-1.0",
	"cpl1.0.0":                              "CPL-1.0",
	"cpol1":                                 "CPOL-1.02",
	"cpol1.02":                              "CPOL-1.02",
	"cpol1.02.0":                            "CPOL-1.02",
	"cronyx":                                "Cronyx",
	"crossword":                             "Crossword",
	"cryptoswift":                           "CryptoSwift",
	"crystalstacker":                        "CrystalStacker",
	"cuaopl1":                               "CUA-OPL-1.0",
	"cuaopl1.0":                             "CUA-OPL-1.0",
	"cuaopl1.0.0":                           "CUA-OPL-1.0",
	"cube":                                  "Cube",
	"cuda1":                                 "C-UDA-1.0",
	"cuda1.0":                               "C-UDA-1.0",
	"cuda1.0.0":                             "C-UDA-1.0",
	"curl":                                  "curl",
	"cvetou":                                "cve-tou",
	"dec3.0.0clause":                        "DEC-3-Clause",
	"dec3.0clause":                          "DEC-3-Clause",
	"dec3clause":                            "DEC-3-Clause",
	"dfsl1":                                 "D-FSL-1.0",
	"dfsl1.0":                               "D-FSL-1.0",
	"dfsl1.0.0":                             "D-FSL-1.0",
	"diffmark":                              "diffmark",
	"dldeby2":                               "DL-DE-BY-2.0",
	"dldeby2.0":                             "DL-DE-BY-2.0",
	"dldeby2.0.0":                           "DL-DE-BY-2.0",
	"dldezero2":                             "DL-DE-ZERO-2.0",
	"dldezero2.0":                           "DL-DE-ZERO-2.0",
	"dldezero2.0.0":                         "DL-DE-ZERO-2.0",
	"doc":                                   "DOC",
	"docbookdtd":                            "DocBook-DTD",
	"docbookschema":                         "DocBook-Schema",
	"docbookstylesheet":                     "DocBook-Stylesheet",
	"docbookxml":                            "DocBook-XML",
	"dotseqn":                               "Dotseqn",
	"drl1":                                  "DRL-1.0",
	"drl1.0":                                "DRL-1.0",
	"drl1.0.0":                              "DRL-1.0",
	"drl1.1":                                "DRL-1.1",
	"drl1.1.0":                              "DRL-1.1",
	"dsdp":                                  "DSDP",
	"dtoa":                                  "dtoa",
	"dvipdfm":                               "dvipdfm",
	"ecl1":                                  "ECL-1.0",
	"ecl1.0":                                "ECL-1.0",
	"ecl1.0.0":                              "ECL-1.0",
	"ecl2":                                  "ECL-2.0",
	"ecl2.0":                                "ECL-2.0",
	"ecl2.0.0":                              "ECL-2.0",
	"ecos2":                                 "eCos-2.0",
	"ecos2.0":                               "eCos-2.0",
	"ecos2.0.0":                             "eCos-2.0",
	"efl1":                                  "EFL-1.0",
	"efl1.0":                                "EFL-1.0",
	"efl1.0.0":                              "EFL-1.0",
	"efl2":                                  "EFL-2.0",
	"efl2.0":                                "EFL-2.0",
	"efl2.0.0":                              "EFL-2.0",
	"egenix":                                "eGenix",
	"elastic2":                              "Elastic-2.0",
	"elastic2.0":                            "Elastic-2.0",
	"elastic2.0.0":                          "Elastic-2.0",
	"entessa":                               "Entessa",
	"epics":                                 "EPICS",
	"epl1":                                  "EPL-1.0",
	"epl1.0":                                "EPL-1.0",
	"epl1.0.0":                              "EPL-1.0",
	"epl2":                                  "EPL-2.0",
	"epl2.0":                                "EPL-2.0",
	"epl2.0.0":                              "EPL-2.0",
	"erlpl1":                                "ErlPL-1.1",
	"erlpl1.1":                              "ErlPL-1.1",
	"erlpl1.1.0":                            "ErlPL-1.1",
	"esaplpermissive2":                      "ESA-PL-permissive-2.4",
	"esaplpermissive2.4":                    "ESA-PL-permissive-2.4",
	"esaplpermissive2.4.0":                  "ESA-PL-permissive-2.4",
	"esaplstrongcopyleft2":                  "ESA-PL-strong-copyleft-2.4",
	"esaplstrongcopyleft2.4":                "ESA-PL-strong-copyleft-2.4",
	"esaplstrongcopyleft2.4.0":              "ESA-PL-strong-copyleft-2.4",
	"esaplweakcopyleft2":                    "ESA-PL-weak-copyleft-2.4",
	"esaplweakcopyleft2.4":                  "ESA-PL-weak-copyleft-2.4",
	"esaplweakcopyleft2.4.0":                "ESA-PL-weak-copyleft-2.4",
	"etalab2":                               "etalab-2.0",
	"etalab2.0":                             "etalab-2.0",
	"etalab2.0.0":                           "etalab-2.0",
	"eudatagrid":                            "EUDatagrid",
	"eupl1":                                 "EUPL-1.0",
	"eupl1.0":                               "EUPL-1.0",
	"eupl1.0.0":                             "EUPL-1.0",
	"eupl1.1":                               "EUPL-1.1",
	"eupl1.1.0":                             "EUPL-1.1",
	"eupl1.2":                               "EUPL-1.2",
	"eupl1.2.0":                             "EUPL-1.2",
	"eurosym":                               "Eurosym",
	"fair":                                  "Fair",
	"fbm":                                   "FBM",
	"fdkaac":                                "FDK-AAC",
	"fergusontwofish":                       "Ferguson-Twofish",
	"frameworx1":                            "Frameworx-1.0",
	"frameworx1.0":                          "Frameworx-1.0",
	"frameworx1.0.0":                        "Frameworx-1.0",
	"freebsddoc":                            "FreeBSD-DOC",
	"freeimage":                             "FreeImage",
	"fsfap":                                 "FSFAP",
	"fsfapnowarrantydisclaimer":             "FSFAP-no-warranty-disclaimer",
	"fsful":                                 "FSFUL",
	"fsfullr":                               "FSFULLR",
	"fsfullrsd":                             "FSFULLRSD",
	"fsfullrwd":                             "FSFULLRWD",
	"fsl1.1.0alv2":                          "FSL-1.1-ALv2",
	"fsl1.1.0mit":                           "FSL-1.1-MIT",
	"fsl1.1alv2":                            "FSL-1.1-ALv2",
	"fsl1.1mit":                             "FSL-1.1-MIT",
	"fsl1alv2":                              "FSL-1.1-ALv2",
	"fsl1mit":                               "FSL-1.1-MIT",
	"ftl":                                   "FTL",
	"furuseth":                              "Furuseth",
	"fwlw":                                  "fwlw",
	"gameprogramminggems":                   "Game-Programming-Gems",
	"gcrdocs":                               "GCR-docs",
	"gd":                                    "GD",
	"genericxts":                            "generic-xts",
	"gfdl1":                                 "GFDL-1.1-only",
	"gfdl1+":                                "GFDL-1.1-or-later",
	"gfdl1+invariants":                      "GFDL-1.1-invariants-or-later",
	"gfdl1+noinvariants":                    "GFDL-1.1-no-invariants-or-later",
	"gfdl1.1":                               "GFDL-1.1-only",
	"gfdl1.1+":                              "GFDL-1.1-or-later",
	"gfdl1.1+invariants":                    "GFDL-1.1-invariants-or-later",
	"gfdl1.1+noinvariants":                  "GFDL-1.1-no-invariants-or-later",
	"gfdl1.1.0":                             "GFDL-1.1-only",
	"gfdl1.1.0+":                            "GFDL-1.1-or-later",
	"gfdl1.1.0+invariants":                  "GFDL-1.1-invariants-or-later",
	"gfdl1.1.0+noinvariants":                "GFDL-1.1-no-invariants-or-later",
	"gfdl1.1.0invariantsonly":               "GFDL-1.1-invariants-only",
	"gfdl1.1.0invariantsorlater":            "GFDL-1.1-invariants-or-later",
	"gfdl1.1.0noinvariantsonly":             "GFDL-1.1-no-invariants-only",
	"gfdl1.1.0noinvariantsorlater":          "GFDL-1.1-no-invariants-or-later",
	"gfdl1.1.0only":                         "GFDL-1.1-only",
	"gfdl1.1.0orlater":                      "GFDL-1.1-or-later",
	"gfdl1.1invariantsonly":                 "GFDL-1.1-invariants-only",
	"gfdl1.1invariantsorlater":              "GFDL-1.1-invariants-or-later",
	"gfdl1.1noinvariantsonly":               "GFDL-1.1-no-invariants-only",
	"gfdl1.1noinvariantsorlater":            "GFDL-1.1-no-invariants-or-later",
	"gfdl1.1only":                           "GFDL-1.1-only",
	"gfdl1.1orlater":                        "GFDL-1.1-or-later",
	"gfdl1.2":                               "GFDL-1.2-only",
	"gfdl1.2+":                              "GFDL-1.2-or-later",
	"gfdl1.2+invariants":                    "GFDL-1.2-invariants-or-later",
	"gfdl1.2+noinvariants":                  "GFDL-1.2-no-invariants-or-later",
	"gfdl1.2.0":                             "GFDL-1.2-only",
	"gfdl1.2.0+":                            "GFDL-1.2-or-later",
	"gfdl1.2.0+invariants":                  "GFDL-1.2-invariants-or-later",
	"gfdl1.2.0+noinvariants":                "GFDL-1.2-no-invariants-or-later",
	"gfdl1.2.0invariantsonly":               "GFDL-1.2-invariants-only",
	"gfdl1.2.0invariantsorlater":            "GFDL-1.2-invariants-or-later",
	"gfdl1.2.0noinvariantsonly":             "GFDL-1.2-no-invariants-only",
	"gfdl1.2.0noinvariantsorlater":          "GFDL-1.2-no-invariants-or-later",
	"gfdl1.2.0only":                         "GFDL-1.2-only",
	"gfdl1.2.0orlater":                      "GFDL-1.2-or-later",
	"gfdl1.2invariantsonly":                 "GFDL-1.2-invariants-only",
	"gfdl1.2invariantsorlater":              "GFDL-1.2-invariants-or-later",
	"gfdl1.2noinvariantsonly":               "GFDL-1.2-no-invariants-only",
	"gfdl1.2noinvariantsorlater":            "GFDL-1.2-no-invariants-or-later",
	"gfdl1.2only":                           "GFDL-1.2-only",
	"gfdl1.2orlater":                        "GFDL-1.2-or-later",
	"gfdl1.3":                               "GFDL-1.3-only",
	"gfdl1.3+":                              "GFDL-1.3-or-later",
	"gfdl1.3+invariants":                    "GFDL-1.3-invariants-or-later",
	"gfdl1.3+noinvariants":                  "GFDL-1.3-no-invariants-or-later",
	"gfdl1.3.0":                             "GFDL-1.3-only",
	"gfdl1.3.0+":                            "GFDL-1.3-or-later",
	"gfdl1.3.0+invariants":                  "GFDL-1.3-invariants-or-later",
	"gfdl1.3.0+noinvariants":                "GFDL-1.3-no-invariants-or-later",
	"gfdl1.3.0invariantsonly":               "GFDL-1.3-invariants-only",
	"gfdl1.3.0invariantsorlater":            "GFDL-1.3-invariants-or-later",
	"gfdl1.3.0noinvariantsonly":             "GFDL-1.3-no-invariants-only",
	"gfdl1.3.0noinvariantsorlater":          "GFDL-1.3-no-invariants-or-later",
	"gfdl1.3.0only":                         "GFDL-1.3-only",
	"gfdl1.3.0orlater":                      "GFDL-1.3-or-later",
	"gfdl1.3invariantsonly":                 "GFDL-1.3-invariants-only",
	"gfdl1.3invariantsorlater":              "GFDL-1.3-invariants-or-later",
	"gfdl1.3noinvariantsonly":               "GFDL-1.3-no-invariants-only",
	"gfdl1.3noinvariantsorlater":            "GFDL-1.3-no-invariants-or-later",
	"gfdl1.3only":                           "GFDL-1.3-only",
	"gfdl1.3orlater":                        "GFDL-1.3-or-later",
	"gfdl1invariantsonly":                   "GFDL-1.1-invariants-only",
	"gfdl1invariantsorlater":                "GFDL-1.1-invariants-or-later",
	"gfdl1noinvariantsonly":                 "GFDL-1.1-no-invariants-only",
	"gfdl1noinvariantsorlater":              "GFDL-1.1-no-invariants-or-later",
	"gfdl1only":                             "GFDL-1.1-only",
	"gfdl1orlater":                          "GFDL-1.1-or-later",
	"giftware":                              "Giftware",
	"gl2.0.0ps":                             "GL2PS",
	"gl2.0ps":                               "GL2PS",
	"gl2ps":                                 "GL2PS",
	"glide":                                 "Glide",
	"glulxe":                                "Glulxe",
	"glwtpl":                                "GLWTPL",
	"gnuplot":                               "gnuplot",
	"gpl1":                                  "GPL-1.0-only",
	"gpl1+":                                 "GPL-1.0-or-later",
	"gpl1.0":                                "GPL-1.0-only",
	"gpl1.0+":                               "GPL-1.0-or-later",
	"gpl1.0.0":                              "GPL-1.0-only",
	"gpl1.0.0+":                             "GPL-1.0-or-later",
	"gpl1.0.0only":                          "GPL-1.0-only",
	"gpl1.0.0orlater":                       "GPL-1.0-or-later",
	"gpl1.0only":                            "GPL-1.0-only",
	"gpl1.0orlater":                         "GPL-1.0-or-later",
	"gpl1only":                              "GPL-1.0-only",
	"gpl1orlater":                           "GPL-1.0-or-later",
	"gpl2":                                  "GPL-2.0-only",
	"gpl2+":                                 "GPL-2.0-or-later",
	"gpl2.0":                                "GPL-2.0-only",
	"gpl2.0+":                               "GPL-2.0-or-later",
	"gpl2.0.0":                              "GPL-2.0-only",
	"gpl2.0.0+":                             "GPL-2.0-or-later",
	"gpl2.0.0only":                          "GPL-2.0-only",
	"gpl2.0.0orlater":                       "GPL-2.0-or-later",
	"gpl2.0.0withautoconfexception":         "GPL-2.0-with-autoconf-exception",
	"gpl2.0.0withbisonexception":            "GPL-2.0-with-bison-exception",
	"gpl2.0.0withclasspathexception":        "GPL-2.0-with-classpath-exception",
	"gpl2.0.0withfontexception":             "GPL-2.0-with-font-exception",
	"gpl2.0.0withgccexception":              "GPL-2.0-with-GCC-exception",
	"gpl2.0only":                            "GPL-2.0-only",
	"gpl2.0orlater":                         "GPL-2.0-or-later",
	"gpl2.0withautoconfexception":           "GPL-2.0-with-autoconf-exception",
	"gpl2.0withbisonexception":              "GPL-2.0-with-bison-exception",
	"gpl2.0withclasspathexception":          "GPL-2.0-with-classpath-exception",
	"gpl2.0withfontexception":               "GPL-2.0-with-font-exception",
	"gpl2.0withgccexception":                "GPL-2.0-with-GCC-exception",
	"gpl2only":                              "GPL-2.0-only",
	"gpl2orlater":                           "GPL-2.0-or-later",
	"gpl2withautoconfexception":             "GPL-2.0-with-autoconf-exception",
	"gpl2withbisonexception":                "GPL-2.0-with-bison-exception",
	"gpl2withclasspathexception":            "GPL-2.0-with-classpath-exception",
	"gpl2withfontexception":                 "GPL-2.0-with-font-exception",
	"gpl2withgccexception":                  "GPL-2.0-with-GCC-exception",
	"gpl3":                                  "GPL-3.0-only",
	"gpl3+":                                 "GPL-3.0-or-later",
	"gpl3.0":                                "GPL-3.0-only",
	"gpl3.0+":                               "GPL-3.0-or-later",
	"gpl3.0.0":                              "GPL-3.0-only",
	"gpl3.0.0+":                             "GPL-3.0-or-later",
	"gpl3.0.0only":                          "GPL-3.0-only",
	"gpl3.0.0orlater":                       "GPL-3.0-or-later",
	"gpl3.0.0withautoconfexception":         "GPL-3.0-with-autoconf-exception",
	"gpl3.0.0withgccexception":              "GPL-3.0-with-GCC-exception",
	"gpl3.0only":                            "GPL-3.0-only",
	"gpl3.0orlater":                         "GPL-3.0-or-later",
	"gpl3.0withautoconfexception":           "GPL-3.0-with-autoconf-exception",
	"gpl3.0withgccexception":                "GPL-3.0-with-GCC-exception",
	"gpl3only":                              "GPL-3.0-only",
	"gpl3orlater":                           "GPL-3.0-or-later",
	"gpl3withautoconfexception":             "GPL-3.0-with-autoconf-exception",
	"gpl3withgccexception":                  "GPL-3.0-with-GCC-exception",
	"graphicsgems":                          "Graphics-Gems",
	"gsoap1.3.0b":                           "gSOAP-1.3b",
	"gsoap1.3b":                             "gSOAP-1.3b",
	"gsoap1b":                               "gSOAP-1.3b",
	"gtkbook":                               "gtkbook",
	"gutmann":                               "Gutmann",
	"haskellreport":                         "HaskellReport",
	"hdf5":                                  "HDF5",
	"hdf5.0":                                "HDF5",
	"hdf5.0.0":                              "HDF5",
	"hdparm":                                "hdparm",
	"hidapi":                                "HIDAPI",
	"hippocratic2":                          "Hippocratic-2.1",
	"hippocratic2.1":                        "Hippocratic-2.1",
	"hippocratic2.1.0":                      "Hippocratic-2.1",
	"hp1986":                                "HP-1986",
	"hp1986.0":                              "HP-1986",
	"hp1986.0.0":                            "HP-1986",
	"hp1989":                                "HP-1989",
	"hp1989.0":                              "HP-1989",
	"hp1989.0.0":                            "HP-1989",
	"hpnd":                                  "HPND",
	"hpnddec":                               "HPND-DEC",
	"hpnddoc":                               "HPND-doc",
	"hpnddocsell":                           "HPND-doc-sell",
	"hpndexport2.0.0us":                     "HPND-export2-US",
	"hpndexport2.0us":                       "HPND-export2-US",
	"hpndexport2us":                         "HPND-export2-US",
	"hpndexportus":                          "HPND-export-US",
	"hpndexportusacknowledgement":           "HPND-export-US-acknowledgement",
	"hpndexportusmodify":                    "HPND-export-US-modify",
	"hpndfenneberglivingston":               "HPND-Fenneberg-Livingston",
	"hpndinriaimag":                         "HPND-INRIA-IMAG",
	"hpndintel":                             "HPND-Intel",
	"hpndkevlinhenney":                      "HPND-Kevlin-Henney",
	"hpndmarkuskuhn":                        "HPND-Markus-Kuhn",
	"hpndmerchantabilityvariant":            "HPND-merchantability-variant",
	"hpndmitdisclaimer":                     "HPND-MIT-disclaimer",
	"hpndnetrek":                            "HPND-Netrek",
	"hpndpbmplus":                           "HPND-Pbmplus",
	"hpndsellmitdisclaimerxserver":          "HPND-sell-MIT-disclaimer-xserver",
	"hpndsellregexpr":                       "HPND-sell-regexpr",
	"hpndsellvariant":                       "HPND-sell-variant",
	"hpndsellvariantcriticalsystems":        "HPND-sell-variant-critical-systems",
	"hpndsellvariantmitdisclaimer":          "HPND-sell-variant-MIT-disclaimer",
	"hpndsellvariantmitdisclaimerrev":       "HPND-sell-variant-MIT-disclaimer-rev",
	"hpndsmc":                               "HPND-SMC",
	"hpnduc":                                "HPND-UC",
	"hpnducexportus":                        "HPND-UC-export-US",
	"htmltidy":                              "HTMLTIDY",
	"hyphenbulgarian":                       "hyphen-bulgarian",
	"ibmpibs":                               "IBM-pibs",
	"icu":                                   "ICU",
	"ieccodecomponentseula":                 "IEC-Code-Components-EULA",
	"ijg":                                   "IJG",
	"ijgshort":                              "IJG-short",
	"imagemagick":                           "ImageMagick",
	"imatix":                                "iMatix",
	"imlib2":                                "Imlib2",
	"imlib2.0":                              "Imlib2",
	"imlib2.0.0":                            "Imlib2",
	"infozip":                               "Info-ZIP",
	"innernet2":                             "Inner-Net-2.0",
	"innernet2.0":                           "Inner-Net-2.0",
	"innernet2.0.0":                         "Inner-Net-2.0",
	"innosetup":                             "InnoSetup",
	"intel":                                 "Intel",
	"intelacpi":                             "Intel-ACPI",
	"interbase1":                            "Interbase-1.0",
	"interbase1.0":                          "Interbase-1.0",
	"interbase1.0.0":                        "Interbase-1.0",
	"ipa":                                   "IPA",
	"ipl1":                                  "IPL-1.0",
	"ipl1.0":                                "IPL-1.0",
	"ipl1.0.0":                              "IPL-1.0",
	"isc":                                   "ISC",
	"iscveillard":                           "ISC-Veillard",
	"isopermission":                         "ISO-permission",
	"jam":                                   "Jam",
	"jasper2":                               "JasPer-2.0",
	"jasper2.0":                             "JasPer-2.0",
	"jasper2.0.0":                           "JasPer-2.0",
	"jove":                                  "jove",
	"jplimage":                              "JPL-image",
	"jpnic":                                 "JPNIC",
	"json":                                  "JSON",
	"kastrup":                               "Kastrup",
	"kazlib":                                "Kazlib",
	"knuthctan":                             "Knuth-CTAN",
	"lal1":                                  "LAL-1.2",
	"lal1.2":                                "LAL-1.2",
	"lal1.2.0":                              "LAL-1.2",
	"lal1.3":                                "LAL-1.3",
	"lal1.3.0":                              "LAL-1.3",
	"latex2.0.0e":                           "Latex2e",
	"latex2.0.0etranslatednotice":           "Latex2e-translated-notice",
	"latex2.0e":                             "Latex2e",
	"latex2.0etranslatednotice":             "Latex2e-translated-notice",
	"latex2e":                               "Latex2e",
	"latex2etranslatednotice":               "Latex2e-translated-notice",
	"leptonica":                             "Leptonica",
	"lgpl2":                                 "LGPL-2.0-only",
	"lgpl2+":                                "LGPL-2.0-or-later",
	"lgpl2.0":                               "LGPL-2.0-only",
	"lgpl2.0+":                              "LGPL-2.0-or-later",
	"lgpl2.0.0":                             "LGPL-2.0-only",
	"lgpl2.0.0+":                            "LGPL-2.0-or-later",
	"lgpl2.0.0only":                         "LGPL-2.0-only",
	"lgpl2.0.0orlater":                      "LGPL-2.0-or-later",
	"lgpl2.0only":                           "LGPL-2.0-only",
	"lgpl2.0orlater":                        "LGPL-2.0-or-later",
	"lgpl2.1":                               "LGPL-2.1-only",
	"lgpl2.1+":                              "LGPL-2.1-or-later",
	"lgpl2.1.0":                             "LGPL-2.1-only",
	"lgpl2.1.0+":                            "LGPL-2.1-or-later",
	"lgpl2.1.0only":                         "LGPL-2.1-only",
	"lgpl2.1.0orlater":                      "LGPL-2.1-or-later",
	"lgpl2.1only":                           "LGPL-2.1-only",
	"lgpl2.1orlater":                        "LGPL-2.1-or-later",
	"lgpl2only":                             "LGPL-2.0-only",
	"lgpl2orlater":                          "LGPL-2.0-or-later",
	"lgpl3":                                 "LGPL-3.0-only",
	"lgpl3+":                                "LGPL-3.0-or-later",
	"lgpl3.0":                               "LGPL-3.0-only",
	"lgpl3.0+":                              "LGPL-3.0-or-later",
	"lgpl3.0.0":                             "LGPL-3.0-only",
	"lgpl3.0.0+":                            "LGPL-3.0-or-later",
	"lgpl3.0.0only":                         "LGPL-3.0-only",
	"lgpl3.0.0orlater":                      "LGPL-3.0-or-later",
	"lgpl3.0only":                           "LGPL-3.0-only",
	"lgpl3.0orlater":                        "LGPL-3.0-or-later",
	"lgpl3only":                             "LGPL-3.0-only",
	"lgpl3orlater":                          "LGPL-3.0-or-later",
	"lgpllr":                                "LGPLLR",
	"libpng":                                "Libpng",
	"libpng1":                               "libpng-1.6.35",
	"libpng1.6":                             "libpng-1.6.35",
	"libpng1.6.35":                          "libpng-1.6.35",
	"libpng2":                               "libpng-2.0",
	"libpng2.0":                             "libpng-2.0",
	"libpng2.0.0":                           "libpng-2.0",
	"libselinux1":                           "libselinux-1.0",
	"libselinux1.0":                         "libselinux-1.0",
	"libselinux1.0.0":                       "libselinux-1.0",
	"libtiff":                               "libtiff",
	"libutildavidnugent":                    "libutil-David-Nugent",
	"liliqp1":                               "LiLiQ-P-1.1",
	"liliqp1.1":                             "LiLiQ-P-1.1",
	"liliqp1.1.0":                           "LiLiQ-P-1.1",
	"liliqr1":                               "LiLiQ-R-1.1",
	"liliqr1.1":                             "LiLiQ-R-1.1",
	"liliqr1.1.0":                           "LiLiQ-R-1.1",
	"liliqrplus1":                           "LiLiQ-Rplus-1.1",
	"liliqrplus1.1":                         "LiLiQ-Rplus-1.1",
	"liliqrplus1.1.0":                       "LiLiQ-Rplus-1.1",
	"linuxmanpages1.0.0para":                "Linux-man-pages-1-para",
	"linuxmanpages1.0para":                  "Linux-man-pages-1-para",
	"linuxmanpages1para":                    "Linux-man-pages-1-para",
	"linuxmanpagescopyleft":                 "Linux-man-pages-copyleft",
	"linuxmanpagescopyleft2.0.0para":        "Linux-man-pages-copyleft-2-para",
	"linuxmanpagescopyleft2.0para":          "Linux-man-pages-copyleft-2-para",
	"linuxmanpagescopyleft2para":            "Linux-man-pages-copyleft-2-para",
	"linuxmanpagescopyleftvar":              "Linux-man-pages-copyleft-var",
	"linuxopenib":                           "Linux-OpenIB",
	"loop":                                  "LOOP",
	"lpddocument":                           "LPD-document",
	"lpl1":                                  "LPL-1.0",
	"lpl1.0":                                "LPL-1.0",
	"lpl1.0.0":                              "LPL-1.0",
	"lpl1.02":                               "LPL-1.02",
	"lpl1.02.0":                             "LPL-1.02",
	"lppl1":                                 "LPPL-1.0",
	"lppl1.0":                               "LPPL-1.0",
	"lppl1.0.0":                             "LPPL-1.0",
	"lppl1.1":                               "LPPL-1.1",
	"lppl1.1.0":                             "LPPL-1.1",
	"lppl1.2":                               "LPPL-1.2",
	"lppl1.2.0":                             "LPPL-1.2",
	"lppl1.3.0a":                            "LPPL-1.3a",
	"lppl1.3.0c":                            "LPPL-1.3c",
	"lppl1.3a":                              "LPPL-1.3a",
	"lppl1.3c":                              "LPPL-1.3c",
	"lppl1a":                                "LPPL-1.3a",
	"lppl1c":                                "LPPL-1.3c",
	"lsof":                                  "lsof",
	"lucidabitmapfonts":                     "Lucida-Bitmap-Fonts",
	"lzmasdk9":                              "LZMA-SDK-9.22",
	"lzmasdk9.11.0to9.20":                   "LZMA-SDK-9.11-to-9.20",
	"lzmasdk9.11to9.20":                     "LZMA-SDK-9.11-to-9.20",
	"lzmasdk9.22":                           "LZMA-SDK-9.22",
	"lzmasdk9.22.0":                         "LZMA-SDK-9.22",
	"lzmasdk9to9.20":                        "LZMA-SDK-9.11-to-9.20",
	"mackerras3.0.0clause":                  "Mackerras-3-Clause",
	"mackerras3.0.0clauseacknowledgment":    "Mackerras-3-Clause-acknowledgment",
	"mackerras3.0clause":                    "Mackerras-3-Clause",
	"mackerras3.0clauseacknowledgment":      "Mackerras-3-Clause-acknowledgment",
	"mackerras3clause":                      "Mackerras-3-Clause",
	"mackerras3clauseacknowledgment":        "Mackerras-3-Clause-acknowledgment",
	"magaz":                                 "magaz",
	"mailprio":                              "mailprio",
	"makeindex":                             "MakeIndex",
	"man2.0.0html":                          "man2html",
	"man2.0html":                            "man2html",
	"man2html":                              "man2html",
	"martinbirgmeier":                       "Martin-Birgmeier",
	"mcpheeslideshow":                       "McPhee-slideshow",
	"metamail":                              "metamail",
	"minpack":                               "Minpack",
	"mips":                                  "MIPS",
	"miros":                                 "MirOS",
	"mit":                                   "MIT",
	"mit0":                                  "MIT-0",
	"mitadvertising":                        "MIT-advertising",
	"mitclick":                              "MIT-Click",
	"mitcmu":                                "MIT-CMU",
	"mitenna":                               "MIT-enna",
	"mitfeh":                                "MIT-feh",
	"mitfestival":                           "MIT-Festival",
	"mitkhronosold":                         "MIT-Khronos-old",
	"mitmodernvariant":                      "MIT-Modern-Variant",
	"mitnfa":                                "MITNFA",
	"mitopengroup":                          "MIT-open-group",
	"mitstk":                                "MIT-STK",
	"mittestregex":                          "MIT-testregex",
	"mitwu":                                 "MIT-Wu",
	"mmixware":                              "MMIXware",
	"mmpl1":                                 "MMPL-1.0.1",
	"mmpl1.0":                               "MMPL-1.0.1",
	"mmpl1.0.1":                             "MMPL-1.0.1",
	"motosoto":                              "Motosoto",
	"mpegssg":                               "MPEG-SSG",
	"mpich2":                                "mpich2",
	"mpich2.0":                              "mpich2",
	"mpich2.0.0":                            "mpich2",
	"mpipermissive":                         "mpi-permissive",
	"mpl1":                                  "MPL-1.0",
	"mpl1.0":                                "MPL-1.0",
	"mpl1.0.0":                              "MPL-1.0",
	"mpl1.1":                                "MPL-1.1",
	"mpl1.1.0":                              "MPL-1.1",
	"mpl2":                                  "MPL-2.0",
	"mpl2.0":                                "MPL-2.0",
	"mpl2.0.0":                              "MPL-2.0",
	"mpl2.0.0nocopyleftexception":           "MPL-2.0-no-copyleft-exception",
	"mpl2.0nocopyleftexception":             "MPL-2.0-no-copyleft-exception",
	"mpl2nocopyleftexception":               "MPL-2.0-no-copyleft-exception",
	"mplus":                                 "mplus",
	"mslpl":                                 "MS-LPL",
	"mspl":                                  "MS-PL",
	"msrl":                                  "MS-RL",
	"mtll":                                  "MTLL",
	"mulanpsl1":                             "MulanPSL-1.0",
	"mulanpsl1.0":                           "MulanPSL-1.0",
	"mulanpsl1.0.0":                         "MulanPSL-1.0",
	"mulanpsl2":                             "MulanPSL-2.0",
	"mulanpsl2.0":                           "MulanPSL-2.0",
	"mulanpsl2.0.0":                         "MulanPSL-2.0",
	"multics":                               "Multics",
	"mup":                                   "Mup",
	"naist2003":                             "NAIST-2003",
	"naist2003.0":                           "NAIST-2003",
	"naist2003.0.0":                         "NAIST-2003",
	"nasa1":                                 "NASA-1.3",
	"nasa1.3":                               "NASA-1.3",
	"nasa1.3.0":                             "NASA-1.3",
	"naumen":                                "Naumen",
	"nbpl1":                                 "NBPL-1.0",
	"nbpl1.0":                               "NBPL-1.0",
	"nbpl1.0.0":                             "NBPL-1.0",
	"ncbipd":                                "NCBI-PD",
	"ncgluk2":                               "NCGL-UK-2.0",
	"ncgluk2.0":                             "NCGL-UK-2.0",
	"ncgluk2.0.0":                           "NCGL-UK-2.0",
	"ncl":                                   "NCL",
	"ncsa":                                  "NCSA",
	"netcdf":                                "NetCDF",
	"netsnmp":                               "Net-SNMP",
	"newsletr":                              "Newsletr",
	"ngpl":                                  "NGPL",
	"ngrep":                                 "ngrep",
	"nicta1":                                "NICTA-1.0",
	"nicta1.0":                              "NICTA-1.0",
	"nicta1.0.0":                            "NICTA-1.0",
	"nistpd":                                "NIST-PD",
	"nistpdfallback":                        "NIST-PD-fallback",
	"nistpdtnt":                             "NIST-PD-TNT",
	"nistsoftware":                          "NIST-Software",
	"nlod1":                                 "NLOD-1.0",
	"nlod1.0":                               "NLOD-1.0",
	"nlod1.0.0":                             "NLOD-1.0",
	"nlod2":                                 "NLOD-2.0",
	"nlod2.0":                               "NLOD-2.0",
	"nlod2.0.0":                             "NLOD-2.0",
	"nlpl":                                  "NLPL",
	"nokia":                                 "Nokia",
	"nosl":                                  "NOSL",
	"noweb":                                 "Noweb",
	"npl1":                                  "NPL-1.0",
	"npl1.0":                                "NPL-1.0",
	"npl1.0.0":                              "NPL-1.0",
	"npl1.1":                                "NPL-1.1",
	"npl1.1.0":                              "NPL-1.1",
	"nposl3":                                "NPOSL-3.0",
	"nposl3.0":                              "NPOSL-3.0",
	"nposl3.0.0":                            "NPOSL-3.0",
	"nrl":                                   "NRL",
	"ntiapd":                                "NTIA-PD",
	"ntp":                                   "NTP",
	"ntp0":                                  "NTP-0",
	"nunit":                                 "Nunit",
	"oar":                                   "OAR",
	"occtpl":                                "OCCT-PL",
	"oclc2":                                 "OCLC-2.0",
	"oclc2.0":                               "OCLC-2.0",
	"oclc2.0.0":                             "OCLC-2.0",
	"odbl1":                                 "ODbL-1.0",
	"odbl1.0":                               "ODbL-1.0",
	"odbl1.0.0":                             "ODbL-1.0",
	"odcby1":                                "ODC-By-1.0",
	"odcby1.0":                              "ODC-By-1.0",
	"odcby1.0.0":                            "ODC-By-1.0",
	"offis":                                 "OFFIS",
	"ofl1":                                  "OFL-1.0",
	"ofl1.0":                                "OFL-1.0",
	"ofl1.0.0":                              "OFL-1.0",
	"ofl1.0.0norfn":                         "OFL-1.0-no-RFN",
	"ofl1.0.0rfn":                           "OFL-1.0-RFN",
	"ofl1.0norfn":                           "OFL-1.0-no-RFN",
	"ofl1.0rfn":                             "OFL-1.0-RFN",
	"ofl1.1":                                "OFL-1.1",
	"ofl1.1.0":                              "OFL-1.1",
	"ofl1.1.0norfn":                         "OFL-1.1-no-RFN",
	"ofl1.1.0rfn":                           "OFL-1.1-RFN",
	"ofl1.1norfn":                           "OFL-1.1-no-RFN",
	"ofl1.1rfn":                             "OFL-1.1-RFN",
	"ofl1norfn":                             "OFL-1.0-no-RFN",
	"ofl1rfn":                               "OFL-1.0-RFN",
	"ogc1":                                  "OGC-1.0",
	"ogc1.0":                                "OGC-1.0",
	"ogc1.0.0":                              "OGC-1.0",
	"ogdltaiwan1":                           "OGDL-Taiwan-1.0",
	"ogdltaiwan1.0":                         "OGDL-Taiwan-1.0",
	"ogdltaiwan1.0.0":                       "OGDL-Taiwan-1.0",
	"oglcanada2":                            "OGL-Canada-2.0",
	"oglcanada2.0":                          "OGL-Canada-2.0",
	"oglcanada2.0.0":                        "OGL-Canada-2.0",
	"ogluk1":                                "OGL-UK-1.0",
	"ogluk1.0":                              "OGL-UK-1.0",
	"ogluk1.0.0":                            "OGL-UK-1.0",
	"ogluk2":                                "OGL-UK-2.0",
	"ogluk2.0":                              "OGL-UK-2.0",
	"ogluk2.0.0":                            "OGL-UK-2.0",
	"ogluk3":                                "OGL-UK-3.0",
	"ogluk3.0":                              "OGL-UK-3.0",
	"ogluk3.0.0":                            "OGL-UK-3.0",
	"ogtsl":                                 "OGTSL",
	"oldap1":                                "OLDAP-1.1",
	"oldap1.1":                              "OLDAP-1.1",
	"oldap1.1.0":                            "OLDAP-1.1",
	"oldap1.2":                              "OLDAP-1.2",
	"oldap1.2.0":                            "OLDAP-1.2",
	"oldap1.3":                              "OLDAP-1.3",
	"oldap1.3.0":                            "OLDAP-1.3",
	"oldap1.4":                              "OLDAP-1.4",
	"oldap1.4.0":                            "OLDAP-1.4",
	"oldap2":                                "OLDAP-2.0",
	"oldap2.0":                              "OLDAP-2.0",
	"oldap2.0.0":                            "OLDAP-2.0",
	"oldap2.0.1":                            "OLDAP-2.0.1",
	"oldap2.1":                              "OLDAP-2.1",
	"oldap2.1.0":                            "OLDAP-2.1",
	"oldap2.2":                              "OLDAP-2.2",
	"oldap2.2.0":                            "OLDAP-2.2",
	"oldap2.2.1":                            "OLDAP-2.2.1",
	"oldap2.2.2":                            "OLDAP-2.2.2",
	"oldap2.3":                              "OLDAP-2.3",
	"oldap2.3.0":                            "OLDAP-2.3",
	"oldap2.4":                              "OLDAP-2.4",
	"oldap2.4.0":                            "OLDAP-2.4",
	"oldap2.5":                              "OLDAP-2.5",
	"oldap2.5.0":                            "OLDAP-2.5",
	"oldap2.6":                              "OLDAP-2.6",
	"oldap2.6.0":                            "OLDAP-2.6",
	"oldap2.7":                              "OLDAP-2.7",
	"oldap2.7.0":                            "OLDAP-2.7",
	"oldap2.8":                              "OLDAP-2.8",
	"oldap2.8.0":                            "OLDAP-2.8",
	"olfl1":                                 "OLFL-1.3",
	"olfl1.3":                               "OLFL-1.3",
	"olfl1.3.0":                             "OLFL-1.3",
	"oml":                                   "OML",
	"openmdw1":                              "OpenMDW-1.0",
	"openmdw1.0":                            "OpenMDW-1.0",
	"openmdw1.0.0":                          "OpenMDW-1.0",
	"openpbs2":                              "OpenPBS-2.3",
	"openpbs2.3":                            "OpenPBS-2.3",
	"openpbs2.3.0":                          "OpenPBS-2.3",
	"openssl":                               "OpenSSL",
	"opensslstandalone":                     "OpenSSL-standalone",
	"openvision":                            "OpenVision",
	"opl1":                                  "OPL-1.0",
	"opl1.0":                                "OPL-1.0",
	"opl1.0.0":                              "OPL-1.0",
	"opluk3":                                "OPL-UK-3.0",
	"opluk3.0":                              "OPL-UK-3.0",
	"opluk3.0.0":                            "OPL-UK-3.0",
	"opubl1":                                "OPUBL-1.0",
	"opubl1.0":                              "OPUBL-1.0",
	"opubl1.0.0":                            "OPUBL-1.0",
	"osc1":                                  "OSC-1.0",
	"osc1.0":                                "OSC-1.0",
	"osc1.0.0":                              "OSC-1.0",
	"osetpl2":                               "OSET-PL-2.1",
	"osetpl2.1":                             "OSET-PL-2.1",
	"osetpl2.1.0":                           "OSET-PL-2.1",
	"osl1":                                  "OSL-1.0",
	"osl1.0":                                "OSL-1.0",
	"osl1.0.0":                              "OSL-1.0",
	"osl1.1":                                "OSL-1.1",
	"osl1.1.0":                              "OSL-1.1",
	"osl2":                                  "OSL-2.0",
	"osl2.0":                                "OSL-2.0",
	"osl2.0.0":                              "OSL-2.0",
	"osl2.1":                                "OSL-2.1",
	"osl2.1.0":                              "OSL-2.1",
	"osl3":                                  "OSL-3.0",
	"osl3.0":                                "OSL-3.0",
	"osl3.0.0":                              "OSL-3.0",
	"ossp":                                  "OSSP",
	"ouda1":                                 "O-UDA-1.0",
	"ouda1.0":                               "O-UDA-1.0",
	"ouda1.0.0":                             "O-UDA-1.0",
	"padl":                                  "PADL",
	"paratypefreefont1":                     "ParaType-Free-Font-1.3",
	"paratypefreefont1.3":                   "ParaType-Free-Font-1.3",
	"paratypefreefont1.3.0":                 "ParaType-Free-Font-1.3",
	"parity6":                               "Parity-6.0.0",
	"parity6.0":                             "Parity-6.0.0",
	"parity6.0.0":                           "Parity-6.0.0",
	"parity7":                               "Parity-7.0.0",
	"parity7.0":                             "Parity-7.0.0",
	"parity7.0.0":                           "Parity-7.0.0",
	"pddl1":                                 "PDDL-1.0",
	"pddl1.0":                               "PDDL-1.0",
	"pddl1.0.0":                             "PDDL-1.0",
	"php3":                                  "PHP-3.0",
	"php3.0":                                "PHP-3.0",
	"php3.0.0":                              "PHP-3.0",
	"php3.01":                               "PHP-3.01",
	"php3.01.0":                             "PHP-3.01",
	"pixar":                                 "Pixar",
	"pkgconf":                               "pkgconf",
	"plexus":                                "Plexus",
	"pnmstitch":                             "pnmstitch",
	"polyformnoncommercial1":                "PolyForm-Noncommercial-1.0.0",
	"polyformnoncommercial1.0":              "PolyForm-Noncommercial-1.0.0",
	"polyformnoncommercial1.0.0":            "PolyForm-Noncommercial-1.0.0",
	"polyformsmallbusiness1":                "PolyForm-Small-Business-1.0.0",
	"polyformsmallbusiness1.0":              "PolyForm-Small-Business-1.0.0",
	"polyformsmallbusiness1.0.0":            "PolyForm-Small-Business-1.0.0",
	"postgresql":                            "PostgreSQL",
	"ppl":                                   "PPL",
	"psf2":                                  "PSF-2.0",
	"psf2.0":                                "PSF-2.0",
	"psf2.0.0":                              "PSF-2.0",
	"psfrag":                                "psfrag",
	"psutils":                               "psutils",
	"python2":                               "Python-2.0",
	"python2.0":                             "Python-2.0",
	"python2.0.0":                           "Python-2.0",
	"python2.0.1":                           "Python-2.0.1",
	"pythonldap":                            "python-ldap",
	"qhull":                                 "Qhull",
	"qpl1":                                  "QPL-1.0",
	"qpl1.0":                                "QPL-1.0",
	"qpl1.0.0":                              "QPL-1.0",
	"qpl1.0.0inria2004":                     "QPL-1.0-INRIA-2004",
	"qpl1.0inria2004":                       "QPL-1.0-INRIA-2004",
	"qpl1inria2004":                         "QPL-1.0-INRIA-2004",
	"radvd":                                 "radvd",
	"rdisc":                                 "Rdisc",
	"rhecos1":                               "RHeCos-1.1",
	"rhecos1.1":                             "RHeCos-1.1",
	"rhecos1.1.0":                           "RHeCos-1.1",
	"rpl1":                                  "RPL-1.1",
	"rpl1.1":                                "RPL-1.1",
	"rpl1.1.0":                              "RPL-1.1",
	"rpl1.5":                                "RPL-1.5",
	"rpl1.5.0":                              "RPL-1.5",
	"rpsl1":                                 "RPSL-1.0",
	"rpsl1.0":                               "RPSL-1.0",
	"rpsl1.0.0":                             "RPSL-1.0",
	"rsamd":                                 "RSA-MD",
	"rscpl":                                 "RSCPL",
	"ruby":                                  "Ruby",
	"rubypty":                               "Ruby-pty",
	"saxpath":                               "Saxpath",
	"saxpd":                                 "SAX-PD",
	"saxpd2":                                "SAX-PD-2.0",
	"saxpd2.0":                              "SAX-PD-2.0",
	"saxpd2.0.0":                            "SAX-PD-2.0",
	"scea":                                  "SCEA",
	"schemereport":                          "SchemeReport",
	"sendmail":                              "Sendmail",
	"sendmail8":                             "Sendmail-8.23",
	"sendmail8.23":                          "Sendmail-8.23",
	"sendmail8.23.0":                        "Sendmail-8.23",
	"sendmailopensource1":                   "Sendmail-Open-Source-1.1",
	"sendmailopensource1.1":                 "Sendmail-Open-Source-1.1",
	"sendmailopensource1.1.0":               "Sendmail-Open-Source-1.1",
	"sgib1":                                 "SGI-B-1.0",
	"sgib1.0":                               "SGI-B-1.0",
	"sgib1.0.0":                             "SGI-B-1.0",
	"sgib1.1":                               "SGI-B-1.1",
	"sgib1.1.0":                             "SGI-B-1.1",
	"sgib2":                                 "SGI-B-2.0",
	"sgib2.0":                               "SGI-B-2.0",
	"sgib2.0.0":                             "SGI-B-2.0",
	"sgiopengl":                             "SGI-OpenGL",
	"sgmlugpm":                              "SGMLUG-PM",
	"sgp4":                                  "SGP4",
	"sgp4.0":                                "SGP4",
	"sgp4.0.0":                              "SGP4",
	"shl0.5":                                "SHL-0.5",
	"shl0.5.0":                              "SHL-0.5",
	"shl0.51":                               "SHL-0.51",
	"shl0.51.0":                             "SHL-0.51",
	"simpl2":                                "SimPL-2.0",
	"simpl2.0":                              "SimPL-2.0",
	"simpl2.0.0":                            "SimPL-2.0",
	"sissl":                                 "SISSL",
	"sissl1":                                "SISSL-1.2",
	"sissl1.2":                              "SISSL-1.2",
	"sissl1.2.0":                            "SISSL-1.2",
	"sl":                                    "SL",
	"sleepycat":                             "Sleepycat",
	"smailgpl":                              "SMAIL-GPL",
	"smlnj":                                 "SMLNJ",
	"smppl":                                 "SMPPL",
	"snia":                                  "SNIA",
	"snprintf":                              "snprintf",
	"sofa":                                  "SOFA",
	"softsurfer":                            "softSurfer",
	"soundex":                               "Soundex",
	"spencer86":                             "Spencer-86",
	"spencer86.0":                           "Spencer-86",
	"spencer86.0.0":                         "Spencer-86",
	"spencer94":                             "Spencer-94",
	"spencer94.0":                           "Spencer-94",
	"spencer94.0.0":                         "Spencer-94",
	"spencer99":                             "Spencer-99",
	"spencer99.0":                           "Spencer-99",
	"spencer99.0.0":                         "Spencer-99",
	"spl1":                                  "SPL-1.0",
	"spl1.0":                                "SPL-1.0",
	"spl1.0.0":                              "SPL-1.0",
	"sshkeyscan":                            "ssh-keyscan",
	"sshopenssh":                            "SSH-OpenSSH",
	"sshshort":                              "SSH-short",
	"ssleaystandalone":                      "SSLeay-standalone",
	"sspl1":                                 "SSPL-1.0",
	"sspl1.0":                               "SSPL-1.0",
	"sspl1.0.0":                             "SSPL-1.0",
	"standardmlnj":                          "SMLNJ",
	"sugarcrm1":                             "SugarCRM-1.1.3",
	"sugarcrm1.1":                           "SugarCRM-1.1.3",
	"sugarcrm1.1.3":                         "SugarCRM-1.1.3",
	"sul1":                                  "SUL-1.0",
	"sul1.0":                                "SUL-1.0",
	"sul1.0.0":                              "SUL-1.0",
	"sunppp":                                "Sun-PPP",
	"sunppp2000":                            "Sun-PPP-2000",
	"sunppp2000.0":                          "Sun-PPP-2000",
	"sunppp2000.0.0":                        "Sun-PPP-2000",
	"sunpro":                                "SunPro",
	"swl":                                   "SWL",
	"swrule":                                "swrule",
	"symlinks":                              "Symlinks",
	"taprohl1":                              "TAPR-OHL-1.0",
	"taprohl1.0":                            "TAPR-OHL-1.0",
	"taprohl1.0.0":                          "TAPR-OHL-1.0",
	"tcl":                                   "TCL",
	"tcpwrappers":                           "TCP-wrappers",
	"tekhvc":                                "TekHVC",
	"termreadkey":                           "TermReadKey",
	"tgppl1":                                "TGPPL-1.0",
	"tgppl1.0":                              "TGPPL-1.0",
	"tgppl1.0.0":                            "TGPPL-1.0",
	"thirdeye":                              "ThirdEye",
	"threeparttable":                        "threeparttable",
	"tmate":                                 "TMate",
	"torque1":                               "TORQUE-1.1",
	"torque1.1":                             "TORQUE-1.1",
	"torque1.1.0":                           "TORQUE-1.1",
	"tosl":                                  "TOSL",
	"tpdl":                                  "TPDL",
	"tpl1":                                  "TPL-1.0",
	"tpl1.0":                                "TPL-1.0",
	"tpl1.0.0":                              "TPL-1.0",
	"trustedqsl":                            "TrustedQSL",
	"ttwl":                                  "TTWL",
	"ttyp0":                                 "TTYP0",
	"tuberlin1":                             "TU-Berlin-1.0",
	"tuberlin1.0":                           "TU-Berlin-1.0",
	"tuberlin1.0.0":                         "TU-Berlin-1.0",
	"tuberlin2":                             "TU-Berlin-2.0",
	"tuberlin2.0":                           "TU-Berlin-2.0",
	"tuberlin2.0.0":                         "TU-Berlin-2.0",
	"ubuntufont1":                           "Ubuntu-font-1.0",
	"ubuntufont1.0":                         "Ubuntu-font-1.0",
	"ubuntufont1.0.0":                       "Ubuntu-font-1.0",
	"ucar":                                  "UCAR",
	"ucl1":                                  "UCL-1.0",
	"ucl1.0":                                "UCL-1.0",
	"ucl1.0.0":                              "UCL-1.0",
	"ulem":                                  "ulem",
	"umichmerit":                            "UMich-Merit",
	"unicode3":                              "Unicode-3.0",
	"unicode3.0":                            "Unicode-3.0",
	"unicode3.0.0":                          "Unicode-3.0",
	"unicodedfs2015":                        "Unicode-DFS-2015",
	"unicodedfs2015.0":                      "Unicode-DFS-2015",
	"unicodedfs2015.0.0":                    "Unicode-DFS-2015",
	"unicodedfs2016":                        "Unicode-DFS-2016",
	"unicodedfs2016.0":                      "Unicode-DFS-2016",
	"unicodedfs2016.0.0":                    "Unicode-DFS-2016",
	"unicodetou":                            "Unicode-TOU",
	"unixcrypt":                             "UnixCrypt",
	"unlicense":                             "Unlicense",
	"unlicenselibtelnet":                    "Unlicense-libtelnet",
	"unlicenselibwhirlpool":                 "Unlicense-libwhirlpool",
	"unrar":                                 "UnRAR",
	"upl1":                                  "UPL-1.0",
	"upl1.0":                                "UPL-1.0",
	"upl1.0.0":                              "UPL-1.0",
	"urtrle":                                "URT-RLE",
	"vim":                                   "Vim",
	"vixiecron":                             "Vixie-Cron",
	"vostrom":                               "VOSTROM",
	"vsl1":                                  "VSL-1.0",
	"vsl1.0":                                "VSL-1.0",
	"vsl1.0.0":                              "VSL-1.0",
	"w3.0.0c":                               "W3C",
	"w3.0.0c19980720":                       "W3C-19980720",
	"w3.0.0c20150513":                       "W3C-20150513",
	"w3.0.0m":                               "w3m",
	"w3.0c":                                 "W3C",
	"w3.0c19980720":                         "W3C-19980720",
	"w3.0c20150513":                         "W3C-20150513",
	"w3.0m":                                 "w3m",
	"w3c":                                   "W3C",
	"w3c19980720":                           "W3C-19980720",
	"w3c20150513":                           "W3C-20150513",
	"w3m":                                   "w3m",
	"watcom1":                               "Watcom-1.0",
	"watcom1.0":                             "Watcom-1.0",
	"watcom1.0.0":                           "Watcom-1.0",
	"widgetworkshop":                        "Widget-Workshop",
	"wordnet":                               "WordNet",
	"wsuipa":                                "Wsuipa",
	"wtfnmfpl":                              "WTFNMFPL",
	"wtfpl":                                 "WTFPL",
	"wwl":                                   "wwl",
	"wxwindows":                             "wxWindows",
	"x11":                                   "X11",
	"x11.0":                                 "X11",
	"x11.0.0":                               "X11",
	"x11.0.0distributemodificationsvariant": "X11-distribute-modifications-variant",
	"x11.0.0nopermitpersons":                "X11-no-permit-persons",
	"x11.0.0swapped":                        "X11-swapped",
	"x11.0distributemodificationsvariant":   "X11-distribute-modifications-variant",
	"x11.0nopermitpersons":                  "X11-no-permit-persons",
	"x11.0swapped":                          "X11-swapped",
	"x11distributemodificationsvariant":     "X11-distribute-modifications-variant",
	"x11nopermitpersons":                    "X11-no-permit-persons",
	"x11swapped":                            "X11-swapped",
	"xdebug1":                               "Xdebug-1.03",
	"xdebug1.03":                            "Xdebug-1.03",
	"xdebug1.03.0":                          "Xdebug-1.03",
	"xerox":                                 "Xerox",
	"xfig":                                  "Xfig",
	"xfree861":                              "XFree86-1.1",
	"xfree861.1":                            "XFree86-1.1",
	"xfree861.1.0":                          "XFree86-1.1",
	"xinetd":                                "xinetd",
	"xkeyboardconfigzinoviev":               "xkeyboard-config-Zinoviev",
	"xlock":                                 "xlock",
	"xnet":                                  "Xnet",
	"xpp":                                   "xpp",
	"xskat":                                 "XSkat",
	"xzoom":                                 "xzoom",
	"ypl1":                                  "YPL-1.0",
	"ypl1.0":                                "YPL-1.0",
	"ypl1.0.0":                              "YPL-1.0",
	"ypl1.1":                                "YPL-1.1",
	"ypl1.1.0":                              "YPL-1.1",
	"zed":                                   "Zed",
	"zeeff":                                 "Zeeff",
	"zend2":                                 "Zend-2.0",
	"zend2.0":                               "Zend-2.0",
	"zend2.0.0":                             "Zend-2.0",
	"zimbra1":                               "Zimbra-1.3",
	"zimbra1.3":                             "Zimbra-1.3",
	"zimbra1.3.0":                           "Zimbra-1.3",
	"zimbra1.4":                             "Zimbra-1.4",
	"zimbra1.4.0":                           "Zimbra-1.4",
	"zlib":                                  "Zlib",
	"zlibacknowledgement":                   "zlib-acknowledgement",
	"zpl1":                                  "ZPL-1.1",
	"zpl1.1":                                "ZPL-1.1",
	"zpl1.1.0":                              "ZPL-1.1",
	"zpl2":                                  "ZPL-2.0",
	"zpl2.0":                                "ZPL-2.0",
	"zpl2.0.0":                              "ZPL-2.0",
	"zpl2.1":                                "ZPL-2.1",
	"zpl2.1.0":                              "ZPL-2.1",
}

// urlToLicense maps license URLs from the seeAlso field to license IDs
var urlToLicense = map[string]string{
	"android.googlesource.com/platform/external/dng_sdk/+/refs/heads/master/source/dng_lossless_jpeg.cpp#16": "Cornell-Lossless-JPEG",
	"apache.org/licenses/LICENSE-1.1": "Apache-1.1",
	"archive.eclipse.org/jetty/8.0.1.v20110908/xref/org/eclipse/jetty/http/security/UnixCrypt.html": "UnixCrypt",
	"artlibre.org/": "LAL-1.3",
	"artlibre.org/licence/lal/licence-art-libre-12/":                                                               "LAL-1.2",
	"assets.ubuntu.com/v1/81e5605d-ubuntu-font-licence-1.0.txt":                                                    "Ubuntu-font-1.0",
	"bits.netizen.com.au/licenses/NOSL/nosl.txt":                                                                   "NOSL",
	"blitiri.com.ar/p/bola/":                                                                                       "BOLA-1.1",
	"blueoakcouncil.org/license/1.0.0":                                                                             "BlueOak-1.0.0",
	"bzip.org/1.0.5/bzip2-manual-1.0.5.html":                                                                       "bzip2-1.0.6",
	"capec.mitre.org/about/termsofuse.html":                                                                        "CAPEC-tou",
	"cdla.dev/computational-use-of-data-agreement-v1-0/":                                                           "C-UDA-1.0",
	"cdla.dev/open-use-of-data-agreement-v1-0/":                                                                    "O-UDA-1.0",
	"cdla.dev/permissive-2-0":                                                                                      "CDLA-Permissive-2.0",
	"cdla.io/permissive-1-0":                                                                                       "CDLA-Permissive-1.0",
	"cdla.io/sharing-1-0":                                                                                          "CDLA-Sharing-1.0",
	"celestrak.org/publications/AIAA/2006-6753/faq.php":                                                            "SGP4",
	"cgit.freedesktop.org/libbsd/tree/man/setproctitle.3bsd":                                                       "libutil-David-Nugent",
	"coil.apotheon.org/plaintext/01.0.txt":                                                                         "COIL-1.0",
	"core.tcl-lang.org/tk/file?name=compat/unistd.h":                                                               "HPND-UC",
	"creativecommons.org/licenses/by-nc-nd/2.0/legalcode":                                                          "CC-BY-NC-ND-2.0",
	"creativecommons.org/licenses/by-nc-nd/2.5/legalcode":                                                          "CC-BY-NC-ND-2.5",
	"creativecommons.org/licenses/by-nc-nd/3.0/de/legalcode":                                                       "CC-BY-NC-ND-3.0-DE",
	"creativecommons.org/licenses/by-nc-nd/3.0/igo/legalcode":                                                      "CC-BY-NC-ND-3.0-IGO",
	"creativecommons.org/licenses/by-nc-nd/3.0/legalcode":                                                          "CC-BY-NC-ND-3.0",
	"creativecommons.org/licenses/by-nc-nd/4.0/legalcode":                                                          "CC-BY-NC-ND-4.0",
	"creativecommons.org/licenses/by-nc-sa/1.0/legalcode":                                                          "CC-BY-NC-SA-1.0",
	"creativecommons.org/licenses/by-nc-sa/2.0/de/legalcode":                                                       "CC-BY-NC-SA-2.0-DE",
	"creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode":                                                       "CC-BY-NC-SA-2.0-FR",
	"creativecommons.org/licenses/by-nc-sa/2.0/legalcode":                                                          "CC-BY-NC-SA-2.0",
	"creativecommons.org/licenses/by-nc-sa/2.0/uk/legalcode":                                                       "CC-BY-NC-SA-2.0-UK",
	"creativecommons.org/licenses/by-nc-sa/2.5/legalcode":                                                          "CC-BY-NC-SA-2.5",
	"creativecommons.org/licenses/by-nc-sa/3.0/de/legalcode":                                                       "CC-BY-NC-SA-3.0-DE",
	"creativecommons.org/licenses/by-nc-sa/3.0/igo/legalcode":                                                      "CC-BY-NC-SA-3.0-IGO",
	"creativecommons.org/licenses/by-nc-sa/3.0/legalcode":                                                          "CC-BY-NC-SA-3.0",
	"creativecommons.org/licenses/by-nc-sa/4.0/legalcode":                                                          "CC-BY-NC-SA-4.0",
	"creativecommons.org/licenses/by-nc/1.0/legalcode":                                                             "CC-BY-NC-1.0",
	"creativecommons.org/licenses/by-nc/2.0/legalcode":                                                             "CC-BY-NC-2.0",
	"creativecommons.org/licenses/by-nc/2.5/legalcode":                                                             "CC-BY-NC-2.5",
	"creativecommons.org/licenses/by-nc/3.0/de/legalcode":                                                          "CC-BY-NC-3.0-DE",
	"creativecommons.org/licenses/by-nc/3.0/legalcode":                                                             "CC-BY-NC-3.0",
	"creativecommons.org/licenses/by-nc/4.0/legalcode":                                                             "CC-BY-NC-4.0",
	"creativecommons.org/licenses/by-nd-nc/1.0/legalcode":                                                          "CC-BY-NC-ND-1.0",
	"creativecommons.org/licenses/by-nd/1.0/legalcode":                                                             "CC-BY-ND-1.0",
	"creativecommons.org/licenses/by-nd/2.0/legalcode":                                                             "CC-BY-ND-2.0",
	"creativecommons.org/licenses/by-nd/2.5/legalcode":                                                             "CC-BY-ND-2.5",
	"creativecommons.org/licenses/by-nd/3.0/de/legalcode":                                                          "CC-BY-ND-3.0-DE",
	"creativecommons.org/licenses/by-nd/3.0/legalcode":                                                             "CC-BY-ND-3.0",
	"creativecommons.org/licenses/by-nd/4.0/legalcode":                                                             "CC-BY-ND-4.0",
	"creativecommons.org/licenses/by-sa/1.0/legalcode":                                                             "CC-BY-SA-1.0",
	"creativecommons.org/licenses/by-sa/2.0/legalcode":                                                             "CC-BY-SA-2.0",
	"creativecommons.org/licenses/by-sa/2.0/uk/legalcode":                                                          "CC-BY-SA-2.0-UK",
	"creativecommons.org/licenses/by-sa/2.1/jp/legalcode":                                                          "CC-BY-SA-2.1-JP",
	"creativecommons.org/licenses/by-sa/2.5/legalcode":                                                             "CC-BY-SA-2.5",
	"creativecommons.org/licenses/by-sa/3.0/at/legalcode":                                                          "CC-BY-SA-3.0-AT",
	"creativecommons.org/licenses/by-sa/3.0/de/legalcode":                                                          "CC-BY-SA-3.0-DE",
	"creativecommons.org/licenses/by-sa/3.0/igo/legalcode":                                                         "CC-BY-SA-3.0-IGO",
	"creativecommons.org/licenses/by-sa/3.0/legalcode":                                                             "CC-BY-SA-3.0",
	"creativecommons.org/licenses/by-sa/4.0/legalcode":                                                             "CC-BY-SA-4.0",
	"creativecommons.org/licenses/by/1.0/legalcode":                                                                "CC-BY-1.0",
	"creativecommons.org/licenses/by/2.0/legalcode":                                                                "CC-BY-2.0",
	"creativecommons.org/licenses/by/2.5/au/legalcode":                                                             "CC-BY-2.5-AU",
	"creativecommons.org/licenses/by/2.5/legalcode":                                                                "CC-BY-2.5",
	"creativecommons.org/licenses/by/3.0/at/legalcode":                                                             "CC-BY-3.0-AT",
	"creativecommons.org/licenses/by/3.0/au/legalcode":                                                             "CC-BY-3.0-AU",
	"creativecommons.org/licenses/by/3.0/de/legalcode":                                                             "CC-BY-3.0-DE",
	"creativecommons.org/licenses/by/3.0/igo/legalcode":                                                            "CC-BY-3.0-IGO",
	"creativecommons.org/licenses/by/3.0/legalcode":                                                                "CC-BY-3.0",
	"creativecommons.org/licenses/by/3.0/nl/legalcode":                                                             "CC-BY-3.0-NL",
	"creativecommons.org/licenses/by/3.0/us/legalcode":                                                             "CC-BY-3.0-US",
	"creativecommons.org/licenses/by/4.0/legalcode":                                                                "CC-BY-4.0",
	"creativecommons.org/licenses/publicdomain/":                                                                   "CC-PDDC",
	"creativecommons.org/licenses/sa/1.0/legalcode":                                                                "CC-SA-1.0",
	"creativecommons.org/publicdomain/mark/1.0/":                                                                   "CC-PDM-1.0",
	"creativecommons.org/publicdomain/zero/1.0/legalcode":                                                          "CC0-1.0",
	"creativecommons.org/share-your-work/cclicenses/":                                                              "CC-PDM-1.0",
	"cryptographicautonomylicense.com/license-text.html":                                                           "CAL-1.0-Combined-Work-Exception",
	"ctan.math.illinois.edu/systems/texlive/tlnet/archive/hyphen-bulgarian.tar.xz":                                 "hyphen-bulgarian",
	"ctan.math.utah.edu/ctan/tex-archive/macros/generic/kastrup/binhex.dtx":                                        "Kastrup",
	"ctan.math.utah.edu/ctan/tex-archive/macros/generic/misc/swrule.sty":                                           "swrule",
	"ctan.org/license/knuth":                                                                                       "Knuth-CTAN",
	"cvs.savannah.gnu.org/viewvc/cvs/ccvs/contrib/check_cvs.in?revision=1.1.4.3&view=markup&pathrev=cvs1-11-23#l2": "check-cvs",
	"data.gov.tw/license":                                                                                          "OGDL-Taiwan-1.0",
	"data.norge.no/nlod/en/1.0":                                                                                    "NLOD-1.0",
	"data.norge.no/nlod/en/2.0":                                                                                    "NLOD-2.0",
	"dev.perl.org/licenses/artistic.html":                                                                          "Artistic-1.0-Perl",
	"dev.w3.org/cvsweb/Amaya/libjpeg/Attic/README?rev=1.2":                                                         "IJG",
	"directory.fsf.org/wiki/License:BSD_4Clause":                                                                   "BSD-4-Clause",
	"directory.fsf.org/wiki/License:BitTorrentOSL1.1":                                                              "BitTorrent-1.1",
	"directory.fsf.org/wiki/License:Fdk":                                                                           "FDK-AAC",
	"doc.qt.io/archives/3.3/license.html":                                                                          "QPL-1.0",
	"doc.qt.nokia.com/3.3/license.html":                                                                            "QPL-1.0",
	"docs.omniverse.nvidia.com/install-guide/latest/common/licenses.html":                                          "AML-glslang",
	"docs.oracle.com/cd/E81115_01/html/E81116/licenses.html":                                                       "man2html",
	"docs.python.org/3/license.html":                                                                               "Python-2.0.1",
	"docs.python.org/3/license.html#execution-tracing":                                                             "HPND-SMC",
	"docubrain.com/sites/default/files/licenses/bitstream-vera.html":                                               "Bitstream-Vera",
	"download.oracle.com/otn-pub/java/licenses/bsd.txt":                                                            "BSD-3-Clause-No-Nuclear-License",
	"ec.europa.eu/idabc/en/document/7330.html":                                                                     "EUPL-1.0",
	"ec.europa.eu/idabc/servlets/Doc027f.pdf?id=31096":                                                             "EUPL-1.0",
	"ecos.sourceware.org/old-license.html":                                                                         "RHeCos-1.1",
	"en.wikipedia.org/wiki/Shared_Source_Initiative#Microsoft_Limited_Public_License_(Ms-LPL)":                     "MS-LPL",
	"enterprise.dejacode.com/licenses/public/naist-2003/#license-text":                                             "NAIST-2003",
	"epics.anl.gov/license/open.php":                                                                               "EPICS",
	"essr.esa.int/license/european-space-agency-public-license-v2-4-permissive-type-3":                             "ESA-PL-permissive-2.4",
	"essr.esa.int/license/european-space-agency-public-license-v2-4-strong-copyleft-type-1":                        "ESA-PL-strong-copyleft-2.4",
	"essr.esa.int/license/european-space-agency-public-license-v2-4-weak-copyleft-type-2":                          "ESA-PL-weak-copyleft-2.4",
	"eu-datagrid.web.cern.ch/eu-datagrid/license.html":                                                             "EUDatagrid",
	"eur-lex.europa.eu/legal-content/EN/TXT/HTML/?uri=CELEX:32017D0863":                                            "EUPL-1.2",
	"fedoraproject.org/wiki/Licensing/AMD_plpa_map_License":                                                        "AMDPLPA",
	"fedoraproject.org/wiki/Licensing/Abstyles":                                                                    "Abstyles",
	"fedoraproject.org/wiki/Licensing/AdobeLicense":                                                                "Adobe-2006",
	"fedoraproject.org/wiki/Licensing/AdobePostscriptAFM":                                                          "APAFML",
	"fedoraproject.org/wiki/Licensing/Afmparse":                                                                    "Afmparse",
	"fedoraproject.org/wiki/Licensing/AmazonDigitalServicesLicense":                                                "ADSL",
	"fedoraproject.org/wiki/Licensing/App-s2p":                                                                     "App-s2p",
	"fedoraproject.org/wiki/Licensing/Apple_MIT_License":                                                           "AML",
	"fedoraproject.org/wiki/Licensing/Apple_Public_Source_License_1.0":                                             "APSL-1.0",
	"fedoraproject.org/wiki/Licensing/BSD#AMPASBSD":                                                                "AMPAS",
	"fedoraproject.org/wiki/Licensing/BSD_Protection_License":                                                      "BSD-Protection",
	"fedoraproject.org/wiki/Licensing/BSD_with_Attribution":                                                        "BSD-3-Clause-Attribution",
	"fedoraproject.org/wiki/Licensing/Bahyph":                                                                      "Bahyph",
	"fedoraproject.org/wiki/Licensing/Barr":                                                                        "Barr",
	"fedoraproject.org/wiki/Licensing/Beerware":                                                                    "Beerware",
	"fedoraproject.org/wiki/Licensing/Borceux":                                                                     "Borceux",
	"fedoraproject.org/wiki/Licensing/Charter#License_Text":                                                        "Bitstream-Charter",
	"fedoraproject.org/wiki/Licensing/Common_Documentation_License":                                                "CDL-1.0",
	"fedoraproject.org/wiki/Licensing/Crossword":                                                                   "Crossword",
	"fedoraproject.org/wiki/Licensing/Cube":                                                                        "Cube",
	"fedoraproject.org/wiki/Licensing/DSDP":                                                                        "DSDP",
	"fedoraproject.org/wiki/Licensing/Dotseqn":                                                                     "Dotseqn",
	"fedoraproject.org/wiki/Licensing/Eurosym":                                                                     "Eurosym",
	"fedoraproject.org/wiki/Licensing/FDK-AAC":                                                                     "FDK-AAC",
	"fedoraproject.org/wiki/Licensing/FSF_Unlimited_License":                                                       "FSFUL",
	"fedoraproject.org/wiki/Licensing/FSF_Unlimited_License#License_Retention_Variant":                             "FSFULLR",
	"fedoraproject.org/wiki/Licensing/Glulxe":                                                                      "Glulxe",
	"fedoraproject.org/wiki/Licensing/Gnuplot":                                                                     "gnuplot",
	"fedoraproject.org/wiki/Licensing/Haskell_Language_Report_License":                                             "HaskellReport",
	"fedoraproject.org/wiki/Licensing/Henry_Spencer_Reg-Ex_Library_License":                                        "Spencer-94",
	"fedoraproject.org/wiki/Licensing/Inner_Net_License":                                                           "Inner-Net-2.0",
	"fedoraproject.org/wiki/Licensing/Intel_ACPI_Software_License_Agreement":                                       "Intel-ACPI",
	"fedoraproject.org/wiki/Licensing/LBNLBSD":                                                                     "BSD-3-Clause-LBNL",
	"fedoraproject.org/wiki/Licensing/Latex2e":                                                                     "Latex2e",
	"fedoraproject.org/wiki/Licensing/Leptonica":                                                                   "Leptonica",
	"fedoraproject.org/wiki/Licensing/MIT":                                                                         "mpich2",
	"fedoraproject.org/wiki/Licensing/MIT#AdobeGlyph":                                                              "Adobe-Glyph",
	"fedoraproject.org/wiki/Licensing/MIT#enna":                                                                    "MIT-enna",
	"fedoraproject.org/wiki/Licensing/MIT#feh":                                                                     "MIT-feh",
	"fedoraproject.org/wiki/Licensing/MITNFA":                                                                      "MITNFA",
	"fedoraproject.org/wiki/Licensing/MIT_With_Advertising":                                                        "MIT-advertising",
	"fedoraproject.org/wiki/Licensing/MakeIndex":                                                                   "MakeIndex",
	"fedoraproject.org/wiki/Licensing/Matrix_Template_Library_License":                                             "MTLL",
	"fedoraproject.org/wiki/Licensing/Mup":                                                                         "Mup",
	"fedoraproject.org/wiki/Licensing/NLPL":                                                                        "NLPL",
	"fedoraproject.org/wiki/Licensing/Newsletr":                                                                    "Newsletr",
	"fedoraproject.org/wiki/Licensing/Noweb":                                                                       "Noweb",
	"fedoraproject.org/wiki/Licensing/OSL1.1":                                                                      "OSL-1.1",
	"fedoraproject.org/wiki/Licensing/Open_Market_License":                                                         "OML",
	"fedoraproject.org/wiki/Licensing/Open_Public_License":                                                         "OPL-1.0",
	"fedoraproject.org/wiki/Licensing/Plexus_Classworlds_License":                                                  "Plexus",
	"fedoraproject.org/wiki/Licensing/Qhull":                                                                       "Qhull",
	"fedoraproject.org/wiki/Licensing/Rdisc_License":                                                               "Rdisc",
	"fedoraproject.org/wiki/Licensing/SNIA_Public_License":                                                         "SNIA",
	"fedoraproject.org/wiki/Licensing/SWL":                                                                         "SWL",
	"fedoraproject.org/wiki/Licensing/Saxpath_License":                                                             "Saxpath",
	"fedoraproject.org/wiki/Licensing/TCL":                                                                         "TCL",
	"fedoraproject.org/wiki/Licensing/TGPPL":                                                                       "TGPPL-1.0",
	"fedoraproject.org/wiki/Licensing/TORQUEv1.1":                                                                  "TORQUE-1.1",
	"fedoraproject.org/wiki/Licensing/TOSL":                                                                        "TOSL",
	"fedoraproject.org/wiki/Licensing/TTWL":                                                                        "TTWL",
	"fedoraproject.org/wiki/Licensing/Threeparttable":                                                              "threeparttable",
	"fedoraproject.org/wiki/Licensing/VOSTROM":                                                                     "VOSTROM",
	"fedoraproject.org/wiki/Licensing/Wsuipa":                                                                      "Wsuipa",
	"fedoraproject.org/wiki/Licensing/XSkat_License":                                                               "XSkat",
	"fedoraproject.org/wiki/Licensing/Xerox":                                                                       "Xerox",
	"fedoraproject.org/wiki/Licensing/Xinetd_License":                                                              "xinetd",
	"fedoraproject.org/wiki/Licensing/Zed":                                                                         "Zed",
	"fedoraproject.org/wiki/Licensing/ZlibWithAcknowledgement":                                                     "zlib-acknowledgement",
	"fedoraproject.org/wiki/Licensing/diffmark":                                                                    "diffmark",
	"fedoraproject.org/wiki/Licensing/dvipdfm":                                                                     "dvipdfm",
	"fedoraproject.org/wiki/Licensing/eGenix.com_Public_License_1.1.0":                                             "eGenix",
	"fedoraproject.org/wiki/Licensing/libtiff":                                                                     "libtiff",
	"fedoraproject.org/wiki/Licensing/psfrag":                                                                      "psfrag",
	"fedoraproject.org/wiki/Licensing/psutils":                                                                     "psutils",
	"fedoraproject.org/wiki/Licensing/softSurfer":                                                                  "softSurfer",
	"fedoraproject.org/wiki/Licensing/xpp":                                                                         "xpp",
	"fedoraproject.org/wiki/Licensing:BSD#Modification_Variant":                                                    "BSD-3-Clause-Modification",
	"fedoraproject.org/wiki/Licensing:Baekmuk?rd=Licensing/Baekmuk":                                                "Baekmuk",
	"fedoraproject.org/wiki/Licensing:CrystalStacker?rd=Licensing/CrystalStacker":                                  "CrystalStacker",
	"fedoraproject.org/wiki/Licensing:MIT#Another_Minimal_variant_(found_in_libatomic_ops)":                        "Boehm-GC",
	"fedoraproject.org/wiki/Licensing:MIT#Modern_Variants":                                                         "MIT-Modern-Variant",
	"fedoraproject.org/wiki/Licensing:MIT#OpenVision_Variant":                                                      "OpenVision",
	"fedoraproject.org/wiki/Licensing:MIT#Xfig_Variant":                                                            "Xfig",
	"fedoraproject.org/wiki/Licensing:MIT?rd=Licensing/MIT#CMU_Style":                                              "MIT-CMU",
	"fedoraproject.org/wiki/Licensing:Mplus?rd=Licensing/mplus":                                                    "mplus",
	"fedoraproject.org/wiki/Licensing:ThorPublicLicense":                                                           "TPL-1.0",
	"firstdonoharm.dev/version/2/1/license.html":                                                                   "Hippocratic-2.1",
	"forge.gouv.qc.ca/licence/fr/liliq-v1-1/":                                                                      "LiLiQ-P-1.1",
	"forge.gouv.qc.ca/licence/liliq-p":                                                                             "LiLiQ-R-1.1",
	"forge.gouv.qc.ca/licence/liliq-p/":                                                                            "LiLiQ-P-1.1",
	"forge.gouv.qc.ca/licence/liliq-r+/":                                                                           "LiLiQ-Rplus-1.1",
	"foss.heptapod.net/python-libs/passlib/-/blob/branch/stable/LICENSE#L70":                                       "UnixCrypt",
	"fossies.org/linux/sendmail/contrib/mailprio":                                                                  "mailprio",
	"fossies.org/linux/tiff/contrib/ras/ras2tif.c":                                                                 "xlock",
	"freeimage.sourceforge.net/freeimage-license.txt":                                                              "FreeImage",
	"freetype.fis.uniroma2.it/FTL.TXT":                                                                             "FTL",
	"fsl.software/FSL-1.1-ALv2.template.md":                                                                        "FSL-1.1-ALv2",
	"fsl.software/FSL-1.1-MIT.template.md":                                                                         "FSL-1.1-MIT",
	"ftp.gnu.org/gnu/aspell/dict/en/aspell6-en-2020.12.07-0.tar.bz2":                                               "BSD-Mark-Modifications",
	"ftp.gnu.org/gnu/aspell/dict/ru/aspell6-ru-0.99f7-1.tar.bz2":                                                   "Aspell-RU",
	"ftp.gnu.org/gnu/non-gnu/chinese-fonts-truetype/LICENSE":                                                       "Arphic-1999",
	"ftp://ftp.tin.org/pub/news/utils/newsx/newsx-1.6.tar.gz":                                                      "Zeeff",
	"gianluca.dellavedova.org/2011/01/03/clarified-artistic-license/":                                              "ClArtistic",
	"git.denx.de/?p=u-boot.git;a=blob;f=arch/powerpc/cpu/ppc4xx/miiphy.c;h=297155fdafa064b955e53e9832de93bfb0cfb85b;hb=9fab4bf4cc077c21e43941866f3f2c196f28670d": "IBM-pibs",
	"git.enlightenment.org/legacy/imlib2.git/tree/COPYING":                                                               "Imlib2",
	"git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/getcpu.2#n4":                                          "Linux-man-pages-1-para",
	"git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/migrate_pages.2#n8":                                   "Linux-man-pages-copyleft-2-para",
	"git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/move_pages.2#n5":                                      "Linux-man-pages-copyleft-2-para",
	"git.kernel.org/pub/scm/docs/man-pages/man-pages.git/tree/man2/set_mempolicy.2#n5":                                   "Linux-man-pages-copyleft-var",
	"git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/tree/drivers/infiniband/core/sa.h":                       "Linux-OpenIB",
	"git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/tree/net/sunrpc/auth_gss/gss_generic_token.c?h=v4.19":    "HPND-sell-variant",
	"git.openldap.org/openldap/openldap/-/blob/master/COPYRIGHT#L55-63":                                                  "BSD-4.3RENO",
	"git.openldap.org/openldap/openldap/-/blob/master/COPYRIGHT?ref_type=heads#L39-51":                                   "Furuseth",
	"git.openldap.org/openldap/openldap/-/blob/master/libraries/libldap/os-local.c?ref_type=heads#L19-23":                "PADL",
	"git.savannah.gnu.org/cgit/freetype/freetype2.git/tree/docs/FTL.TXT":                                                 "FTL",
	"git.savannah.gnu.org/cgit/gcl.git/tree/gcl/lsp/gcl_loop.lsp?h=Version_2_6_13pre":                                    "LOOP",
	"git.savannah.gnu.org/cgit/gnulib.git/tree/modules/COPYING?id=7b08932179d0d6b017f7df01a2ddf6e096b038e3":              "FSFULLRSD",
	"git.savannah.gnu.org/cgit/indent.git/tree/doc/indent.texi?id=a74c6b4ee49397cf330b333da1042bffa60ed14f#n1788":        "BSD-4.3TAHOE",
	"git.savannah.gnu.org/cgit/indent.git/tree/doc/indent.texi?id=a74c6b4ee49397cf330b333da1042bffa60ed14f#n74":          "Latex2e-translated-notice",
	"git.savannah.gnu.org/cgit/kazlib.git/tree/except.c?id=0062df360c2d17d57f6af19b0e444c51feb99036":                     "Kazlib",
	"git.savannah.gnu.org/cgit/wget.git/tree/util/trunc.c?h=v1.21.3&id=40747a11e44ced5a8ac628a41f879ced3e2ebce9#n6":      "FSFAP-no-warranty-disclaimer",
	"git.sr.ht/~nabijaczleweli/ossp-var":                                                                                 "OSSP",
	"github.com/389ds/389-ds-base/blob/main/ldap/include/sysexits-compat.h#L15":                                          "BSD-4.3TAHOE",
	"github.com/AcademySoftwareFoundation/foundation/blob/main/digital_assets/aswf_digital_assets_license_v1.0.txt":      "ASWF-Digital-Assets-1.0",
	"github.com/AcademySoftwareFoundation/foundation/blob/main/digital_assets/aswf_digital_assets_license_v1.1.txt":      "ASWF-Digital-Assets-1.1",
	"github.com/AdaCore/gnatcoll-core/blob/master/docs/index.rst":                                                        "AdaCore-doc",
	"github.com/AdaCore/gnatcoll-db/blob/master/docs/index.rst":                                                          "AdaCore-doc",
	"github.com/AdaCore/xmlada/blob/master/docs/index.rst":                                                               "AdaCore-doc",
	"github.com/BuildCraft/BuildCraft/blob/623d323b1868712f29f4a8b0979a02e8d1835131/LICENSE":                             "MMPL-1.0.1",
	"github.com/CommunitySpecification/1.0/blob/master/1._Community_Specification_License-v1.md":                         "Community-Spec-1.0",
	"github.com/CorsixTH/deps/blob/fd339a9f526d1d9c9f01ccf39e438a015da50035/licences/libgsm.txt":                         "TU-Berlin-2.0",
	"github.com/Cyan4973/xxHash/blob/dev/doc/xxhash_spec.md":                                                             "LPD-document",
	"github.com/DISIC/politique-de-contribution-open-source/blob/master/LICENSE.pdf":                                     "etalab-2.0",
	"github.com/Distrotech/hdparm/blob/4517550db29a91420fb2b020349523b1b4512df2/LICENSE.TXT":                             "hdparm",
	"github.com/Distrotech/transfig/blob/master/transfig/transfig.c":                                                     "Xfig",
	"github.com/DrItanium/maya/blob/master/LICENSE.CLIPS":                                                                "Clips",
	"github.com/Dual-Life/mime-base64/blob/master/Base64.xs#L12":                                                         "metamail",
	"github.com/EthicalSource/hippocratic-license/blob/58c0e646d64ff6fbee275bfe2b9492f914e3ab2a/LICENSE.txt":             "Hippocratic-2.1",
	"github.com/FreeRADIUS/freeradius-client/blob/master/COPYRIGHT#L32":                                                  "HPND-Fenneberg-Livingston",
	"github.com/GNOME/gcr/blob/master/docs/COPYING":                                                                      "GCR-docs",
	"github.com/GNOME/libxml2/blob/master/dict.c":                                                                        "ISC-Veillard",
	"github.com/HDFGroup/hdf5/?tab=License-1-ov-file#readme":                                                             "HDF5",
	"github.com/KhronosGroup/SPIRV-Cross/blob/main/LICENSES/LicenseRef-KhronosFreeUse.txt":                               "MIT-Khronos-old",
	"github.com/KhronosGroup/glslang/blob/main/LICENSE.txt#L949":                                                         "AML-glslang",
	"github.com/MariaDB/server/blob/11.6/libmysqld/lib_sql.cc":                                                           "Boehm-GC-without-fee",
	"github.com/Neo23x0/sigma/blob/master/LICENSE.Detection.Rules.md":                                                    "DRL-1.0",
	"github.com/OGRECave/ogre/blob/master/OgreMain/include/OgreSingleton.h#L28C3-L35C46":                                 "Game-Programming-Gems",
	"github.com/Perl/perl5/blob/blead/util.c#L6136":                                                                      "Martin-Birgmeier",
	"github.com/PixarAnimationStudios/OpenSubdiv/blob/v3_5_0/opensubdiv/version.cpp#L2-L22":                              "Pixar",
	"github.com/PixarAnimationStudios/OpenSubdiv/raw/v3_5_0/LICENSE.txt":                                                 "Pixar",
	"github.com/RTimothyEdwards/magic/blob/master/LICENSE":                                                               "HPND-UC-export-US",
	"github.com/SELinuxProject/selinux/blob/master/libselinux/LICENSE":                                                   "libselinux-1.0",
	"github.com/SWI-Prolog/packages-clib/blob/master/sha1/brg_endian.h":                                                  "Brian-Gladman-3-Clause",
	"github.com/SWI-Prolog/packages-xpce/blob/161a40cd82004f731ba48024f9d30af388a7edf5/src/img/gifwrite.c#L21-L26":       "FBM",
	"github.com/SWI-Prolog/swipl-devel/blob/master/src/os/dtoa.c":                                                        "dtoa",
	"github.com/SigmaHQ/Detection-Rule-License/blob/6ec7fbde6101d101b5b5d1fcb8f9b69fbc76c04a/LICENSE.Detection.Rules.md": "DRL-1.1",
	"github.com/Slicer/Slicer/blob/main/License.txt":                                                                     "3D-Slicer-1.0",
	"github.com/Unidata/UDUNITS-2/blob/master/COPYRIGHT":                                                                 "UCAR",
	"github.com/acpica/acpica/blob/master/source/common/acfileio.c#L119":                                                 "BSD-3-Clause-acpica",
	"github.com/adaptivecomputing/torque/blob/master/PBS_License.txt":                                                    "OpenPBS-2.3",
	"github.com/adversary-org/wtfnmf/raw/3f2cd8235a64350a57a51b9739715edaea63ec1a/COPYING.WTFNMFPL-utf8":                 "WTFNMFPL",
	"github.com/adversary-org/wtfnmf/raw/refs/tags/1.0/COPYING.WTFNMFPL":                                                 "WTFNMFPL",
	"github.com/ap/Text-Tabs/blob/master/lib.modern/Text/Tabs.pm#L148":                                                   "TTWL",
	"github.com/apache/apr/blob/trunk/LICENSE#L298C6-L298C29":                                                            "Caldera-no-preamble",
	"github.com/audacious-media-player/audacious/blob/master/COPYING":                                                    "BSD-2-Clause-pkgconf-disclaimer",
	"github.com/audacious-media-player/audacious/blob/master/src/audacious/main.cc":                                      "BSD-2-Clause-pkgconf-disclaimer",
	"github.com/aws/mit-0": "MIT-0",
	"github.com/awsdocs/aws-cloud9-user-guide/blob/master/LICENSE-SAMPLECODE":                                                 "MIT-0",
	"github.com/bagder/curl/blob/master/COPYING":                                                                              "curl",
	"github.com/bcrypt-ruby/bcrypt-ruby/blob/master/ext/mri/crypt_blowfish.c":                                                 "bcrypt-Solar-Designer",
	"github.com/blakemcbride/eclipse-lisp/blob/master/lisp/loop.lisp":                                                         "LOOP",
	"github.com/bleargh45/Data-UUID/blob/master/LICENSE":                                                                      "HP-1989",
	"github.com/chromium/octane/blob/master/crypto.js":                                                                        "MIT-Wu",
	"github.com/cl-adams/adams/blob/master/LICENSE.md":                                                                        "LOOP",
	"github.com/copyleft-next/copyleft-next/blob/master/Releases/copyleft-next-0.3.0":                                         "copyleft-next-0.3.0",
	"github.com/copyleft-next/copyleft-next/blob/master/Releases/copyleft-next-0.3.1":                                         "copyleft-next-0.3.1",
	"github.com/cyrusimap/cyrus-sasl/blob/master/COPYING":                                                                     "BSD-Attribution-HPND-disclaimer",
	"github.com/dcblake/SMP/blob/master/Documentation/License.txt":                                                            "SMPPL",
	"github.com/dfateyev/libwhirlpool/blob/master/README#L27":                                                                 "Unlicense-libwhirlpool",
	"github.com/docbook/xslt10-stylesheets/blob/efd62655c11cc8773708df7a843613fa1e932bf8/xsl/COPYING#L27":                     "DocBook-XML",
	"github.com/docbook/xslt10-stylesheets/blob/efd62655c11cc8773708df7a843613fa1e932bf8/xsl/assembly/schema/docbook51b7.rnc": "DocBook-Schema",
	"github.com/dotnet/runtime/blob/55e1ac7c07df62c4108d4acedf78f77574470ce5/src/libraries/System.Text.RegularExpressions/tests/FunctionalTests/AttRegexTests.cs#L12-L28": "MIT-testregex",
	"github.com/elastic/elasticsearch/blob/master/licenses/ELASTIC-LICENSE-2.0.txt":                                                                                       "Elastic-2.0",
	"github.com/erich666/GraphicsGems/blob/master/LICENSE.md":                                                                                                             "Graphics-Gems",
	"github.com/fedeinthemix/chez-srfi/blob/master/srfi/LICENSE":                                                                                                          "X11-swapped",
	"github.com/festvox/flite/blob/master/COPYING":                                                                                                                        "MIT-Festival",
	"github.com/festvox/speech_tools/blob/master/COPYING":                                                                                                                 "MIT-Festival",
	"github.com/file/file/blob/master/COPYING":                                                                                                                            "BSD-2-Clause-Darwin",
	"github.com/freebsd/freebsd-src/blob/main/lib/msun/src/e_acosh.c":                                                                                                     "SunPro",
	"github.com/freebsd/freebsd-src/blob/main/lib/msun/src/e_lgammal.c":                                                                                                   "SunPro",
	"github.com/gabegundy/atlserver/blob/master/License.txt":                                                                                                              "MS-LPL",
	"github.com/greymass/swift-eosio/blob/master/LICENSE":                                                                                                                 "BSD-3-Clause-No-Military-License",
	"github.com/hamano/man2html/blob/master/man2html.c":                                                                                                                   "man2html",
	"github.com/htacg/tidy-html5/blob/next/README/LICENSE.md":                                                                                                             "HTMLTIDY",
	"github.com/ivmai/libatomic_ops/blob/master/LICENSE":                                                                                                                  "Boehm-GC",
	"github.com/jonathanstowe/TermReadKey/blob/master/README#L9-L10":                                                                                                      "TermReadKey",
	"github.com/jonmacs/jove/blob/4_17/LICENSE":                                                                                                                           "jove",
	"github.com/jpr5/ngrep/blob/master/LICENSE":                                                                                                                           "ngrep",
	"github.com/jrsoftware/issrc/blob/HEAD/license.txt":                                                                                                                   "InnoSetup",
	"github.com/jsommers/pytricia/blob/master/patricia.c#L33-L67":                                                                                                         "BSD-4-Clause",
	"github.com/kfish/xsel/blob/master/COPYING":                                                                                                                           "HPND-sell-variant",
	"github.com/kohler/t1utils/blob/master/LICENSE":                                                                                                                       "MIT-Click",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L111-L133":                                                                                                        "HPND-export2-US",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L1157-L1182":                                                                                                      "HPND-export-US-modify",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L140-L156":                                                                                                        "Brian-Gladman-2-Clause",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L66-L98":                                                                                                          "OpenVision",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L664-L690":                                                                                                        "BSD-2-Clause-first-lines",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L718-L728":                                                                                                        "CMU-Mach-nodoc",
	"github.com/krb5/krb5/blob/krb5-1.21.2-final/NOTICE#L831-L852":                                                                                                        "HPND-export-US-acknowledgement",
	"github.com/krzyzanowskim/CryptoSwift/blob/main/LICENSE":                                                                                                              "CryptoSwift",
	"github.com/lattera/freebsd/blob/master/sys/cam/cam.c#L4":                                                                                                             "BSD-Source-beginning-file",
	"github.com/libcheck/check/blob/master/checkmk/checkmk.in":                                                                                                            "checkmk",
	"github.com/libjpeg-turbo/libjpeg-turbo/blob/main/README.ijg#L117-L161":                                                                                               "IJG",
	"github.com/lsof-org/lsof/blob/master/COPYING":                                                                                                                        "lsof",
	"github.com/maranget/hevea/blob/master/LICENSE":                                                                                                                       "QPL-1.0-INRIA-2004",
	"github.com/me-shaon/GLWTPL/commit/da5f6bc734095efbacb442c0b31e33a65b9d6e85":                                                                                          "GLWTPL",
	"github.com/mhogomchungu/zuluCrypt/blob/master/external_libraries/tcplay/generic_xts.c":                                                                               "generic-xts",
	"github.com/microsoft/Computational-Use-of-Data-Agreement/blob/master/C-UDA-1.0.md":                                                                                   "C-UDA-1.0",
	"github.com/microsoft/Open-Use-of-Data-Agreement/blob/v1.0/O-UDA-1.0.md":                                                                                              "O-UDA-1.0",
	"github.com/mirror/ncurses/blob/master/COPYING":                                                                                                                       "X11-distribute-modifications-variant",
	"github.com/mm2/Little-CMS/blob/master/src/cmssm.c#L207":                                                                                                              "softSurfer",
	"github.com/mruby/mruby/blob/83d12f8d52522cdb7c8cc46fad34821359f453e6/mrbgems/mruby-dir/src/Win/dirent.c#L127-L140":                                                   "HPND-Kevlin-Henney",
	"github.com/mtoyoda/sl/blob/master/LICENSE":                                                                                                                           "SL",
	"github.com/n8n-io/n8n/blob/master/LICENSE.md":                                                                                                                        "SUL-1.0",
	"github.com/ncbi/datasets/blob/0ea4cd16b61e5b799d9cc55aecfa016d6c9bd2bf/LICENSE.md":                                                                                   "NCBI-PD",
	"github.com/ncbi/datasets/blob/master/LICENSE.md":                                                                                                                     "NCBI-PD",
	"github.com/ncbi/egapx/blob/08930b9dec0c69b2d1a05e5153c7b95ef0a3eb0f/LICENSE":                                                                                         "NCBI-PD",
	"github.com/ncbi/gprobe/blob/de64d30fee8b4c4013094d7d3139ea89b5dd1ace/LICENSE":                                                                                        "NCBI-PD",
	"github.com/ncbi/sra-tools/blob/e8e5b6af4edc460156ad9ce5902d0779cffbf685/LICENSE":                                                                                     "NCBI-PD",
	"github.com/nodejs/node/blob/4a19cc8947b1bba2b2d27816ec3d0edf9b28e503/LICENSE#L343":                                                                                   "NAIST-2003",
	"github.com/novnc/noVNC/blob/master/core/crypto/des.js#L24":                                                                                                           "Widget-Workshop",
	"github.com/oetiker/rrdtool-1.x/blob/master/src/plbasename.c#L8-L11":                                                                                                  "gtkbook",
	"github.com/open-quantum-safe/liboqs/blob/40b01fdbb270f8614fde30e65d30e9da18c02393/src/common/rand/rand_nist.c#L1-L15":                                                "NIST-Software",
	"github.com/openjdk/jdk/blob/6162e2c5213c5dd7c1127fd9616b543efa898962/LICENSE":                                                                                        "GPL-2.0-or-later",
	"github.com/openssh/openssh-portable/blob/1b11ea7c58cd5c59838b5fa574cd456d6047b2d4/LICENCE#L10":                                                                       "SSH-OpenSSH",
	"github.com/openssh/openssh-portable/blob/1b11ea7c58cd5c59838b5fa574cd456d6047b2d4/pathnames.h":                                                                       "SSH-short",
	"github.com/openssh/openssh-portable/blob/master/LICENCE#L82":                                                                                                         "ssh-keyscan",
	"github.com/openssh/openssh-portable/blob/master/openbsd-compat/bsd-snprintf.c#L2":                                                                                    "snprintf",
	"github.com/pexip/os-perl/blob/833cf4c86cc465ccfc627ff16db67e783156a248/debian/copyright#L2720-L2845":                                                                 "Artistic-dist",
	"github.com/pkgconf/pkgconf/blob/master/cli/main.c#L8":                                                                                                                "pkgconf",
	"github.com/ppp-project/ppp/blob/master/modules/ppp_ahdlc.c#L7-L19":                                                                                                   "Sun-PPP-2000",
	"github.com/ppp-project/ppp/blob/master/pppd/auth.c#L6-L28":                                                                                                           "Mackerras-3-Clause-acknowledgment",
	"github.com/ppp-project/ppp/blob/master/pppd/chap_ms.c#L6-L28":                                                                                                        "Mackerras-3-Clause",
	"github.com/ppp-project/ppp/blob/master/pppd/eap.c#L7-L16":                                                                                                            "Sun-PPP",
	"github.com/ppp-project/ppp/blob/master/pppd/ipv6cp.c#L75-L83":                                                                                                        "HPND-INRIA-IMAG",
	"github.com/protegeproject/protege/blob/master/license.txt":                                                                                                           "BSD-2-Clause-Views",
	"github.com/python-excel/xlrd/blob/master/LICENSE#L33":                                                                                                                "BSD-Advertising-Acknowledgement",
	"github.com/python-ldap/python-ldap/blob/main/LICENCE":                                                                                                                "python-ldap",
	"github.com/python-pillow/Pillow/blob/fffb426092c8db24a5f4b6df243a8a3c01fb63cd/LICENSE":                                                                               "MIT-CMU",
	"github.com/python/cpython/blob/main/LICENSE":                                                                                                                         "Python-2.0.1",
	"github.com/pythongssapi/k5test/blob/v0.10.3/K5TEST-LICENSE.txt":                                                                                                      "HPND-export-US-modify",
	"github.com/radcli/radcli/blob/master/COPYRIGHT#L34":                                                                                                                  "HPND-Fenneberg-Livingston",
	"github.com/radcli/radcli/blob/master/COPYRIGHT#L64":                                                                                                                  "UMich-Merit",
	"github.com/radvd-project/radvd/blob/master/COPYRIGHT":                                                                                                                "radvd",
	"github.com/robbiehanson/CocoaHTTPServer/blob/master/LICENSE.txt":                                                                                                     "BSD-Source-Code",
	"github.com/ruby/ruby/blob/9f6deaa6888a423720b4b127b5314f0ad26cc2e6/ext/pty/pty.c#L775-L786":                                                                          "Ruby-pty",
	"github.com/ruby/ruby/commit/0a64817fb80016030c03518fb9459f63c11605ea#diff-ef5fa30838d6d0cecad9e675cc50b24628cfe2cb277c346053fafcc36c91c204":                          "Ruby-pty",
	"github.com/ruby/ruby/commit/0a64817fb80016030c03518fb9459f63c11605ea#diff-fedf217c1ce44bda01f0a678d3ff8b198bed478754d699c527a698ad933979a0":                          "Ruby-pty",
	"github.com/scummvm/scummvm/blob/v2.8.0/LICENSES/CatharonLicense.txt":                                                                                                 "Catharon",
	"github.com/seanmiddleditch/libtelnet/blob/develop/COPYING":                                                                                                           "Unlicense-libtelnet",
	"github.com/sigmavirus24/x11-ssh-askpass/blob/master/README":                                                                                                          "HPND-sell-variant-MIT-disclaimer",
	"github.com/sigmavirus24/x11-ssh-askpass/blob/master/dynlist.c":                                                                                                       "HPND-sell-variant-MIT-disclaimer-rev",
	"github.com/signal11/hidapi/blob/master/LICENSE-orig.txt":                                                                                                             "HIDAPI",
	"github.com/slogan621/gtkbook":                                                                                                                                        "gtkbook",
	"github.com/swh/ladspa/blob/7bf6f3799fdba70fda297c2d8fd9f526803d9680/gsm/COPYRIGHT":                                                                                   "TU-Berlin-1.0",
	"github.com/tats/w3m/blob/master/COPYING":                                                                                                                             "w3m",
	"github.com/tcheneau/Routing/blob/f09f46fcfe636107f22f2c98348188a65a135d98/README.md":                                                                                 "NIST-PD",
	"github.com/tcheneau/simpleRPL/blob/e645e69e38dd4e3ccfeceb2db8cba05b7c2e0cd3/LICENSE.txt":                                                                             "NIST-PD",
	"github.com/thestk/stk/blob/6aacd357d76250bb7da2b1ddf675651828784bbc/LICENSE":                                                                                         "MIT-STK",
	"github.com/trusteddomainproject/OpenDMARC/blob/master/LICENSE.Sendmail":                                                                                              "Sendmail-Open-Source-1.1",
	"github.com/tytso/e2fsprogs/blob/master/lib/et/et_name.c":                                                                                                             "NTP-0",
	"github.com/uim/libgcroots/blob/master/COPYING":                                                                                                                       "Boehm-GC",
	"github.com/usnistgov/fipy/blob/86aaa5c2ba2c6f1be19593c5986071cf6568cc34/LICENSE.rst":                                                                                 "NIST-PD-fallback",
	"github.com/usnistgov/jsip/blob/59700e6926cbe96c5cdae897d9a7d2656b42abe3/LICENSE":                                                                                     "NIST-PD-fallback",
	"github.com/vixie/cron/tree/545b3f5246824a9cda5905eeb7cf019c95e66995":                                                                                                 "Vixie-Cron",
	"github.com/vstroebel/jpeg-encoder/blob/main/src/fdct.rs#L1-L72":                                                                                                      "IJG",
	"github.com/wernerd/ZRTPCPP/blob/6b3cd8e6783642292bad0c21e3e5e5ce45ff3e03/cryptcommon/twofish.c#L113C3-L127":                                                          "Ferguson-Twofish",
	"github.com/westes/flex/blob/master/COPYING":                                                                                                                          "BSD-3-Clause-flex",
	"github.com/xdebug/xdebug/blob/master/LICENSE":                                                                                                                        "Xdebug-1.03",
	"github.com/xmlark/msv/blob/b9316e2f2270bc1606952ea4939ec87fbba157f3/xsdlib/src/main/java/com/sun/msv/datatype/regexp/InternalImpl.java":                              "BSD-3-Clause-Sun",
	"github.com/yuwenlong/longphp/blob/25dfb70cc2a466dc4bb55ba30901cbce08d164b5/LICENSE":                                                                                  "MulanPSL-1.0",
	"github.com/zdohnal/hplip/blob/master/COPYING#L939":                                                                                                                   "BSD-3-Clause-HP",
	"gitlab.com/agmartin/linuxdoc-tools/-/blob/master/iso-entities/COPYING?ref_type=heads":                                                                                "ISO-permission",
	"gitlab.com/bacula-org/bacula/-/blob/Branch-11.0/bacula/LICENSE-FOSS?ref_type=heads#L245":                                                                             "HPND-sell-regexpr",
	"gitlab.com/embeddable-common-lisp/ecl/-/blob/develop/src/lsp/loop.lsp":                                                                                               "LOOP",
	"gitlab.com/libeigen/eigen/-/blob/master/COPYING.MINPACK":                                                                                                             "Minpack",
	"gitlab.common-lisp.net/cmucl/cmucl/-/blob/master/src/code/loop.lisp":                                                                                                 "LOOP",
	"gitlab.freedesktop.org/freetype/freetype/-/raw/master/docs/FTL.TXT":                                                                                                  "FTL",
	"gitlab.freedesktop.org/libopenraw/libopenraw/blob/master/lib/ljpegdecompressor.cpp#L32":                                                                              "Cornell-Lossless-JPEG",
	"gitlab.freedesktop.org/mesa/glw/-/blob/master/README?ref_type=heads":                                                                                                 "SGI-OpenGL",
	"gitlab.freedesktop.org/pipewire/pipewire/-/blob/master/src/modules/module-filter-chain/pffft.c?ref_type=heads#L1-52":                                                 "NCL",
	"gitlab.freedesktop.org/xkeyboard-config/xkeyboard-config/-/blob/959538769bfad6a73bdf34275d46520ec0f9cbb5/COPYING#L176-185":                                           "hyphen-bulgarian",
	"gitlab.freedesktop.org/xkeyboard-config/xkeyboard-config/-/blob/master/COPYING?ref_type=heads#L178":                                                                  "xkeyboard-config-Zinoviev",
	"gitlab.freedesktop.org/xorg/app/iceauth/-/blob/master/COPYING":                                                                                                       "MIT-open-group",
	"gitlab.freedesktop.org/xorg/app/xauth/-/blob/master/COPYING":                                                                                                         "MIT-open-group",
	"gitlab.freedesktop.org/xorg/app/xkbcomp/-/blob/master/COPYING?ref_type=heads#L69":                                                                                    "HPND-DEC",
	"gitlab.freedesktop.org/xorg/app/xsetroot/-/blob/master/COPYING":                                                                                                      "MIT-open-group",
	"gitlab.freedesktop.org/xorg/driver/xf86-video-voodoo/-/blob/68a5b6d98ae34749cca889f4373b4043d00bfe6a/src/voodoo_dga.c#L12-33":                                        "HPND-sell-variant-critical-systems",
	"gitlab.freedesktop.org/xorg/font/adobe-utopia-100dpi/-/blob/master/COPYING?ref_type=heads":                                                                           "Adobe-Utopia",
	"gitlab.freedesktop.org/xorg/font/alias/-/blob/master/COPYING":                                                                                                        "Cronyx",
	"gitlab.freedesktop.org/xorg/font/bh-100dpi/-/blob/master/COPYING?ref_type=heads":                                                                                     "Lucida-Bitmap-Fonts",
	"gitlab.freedesktop.org/xorg/font/cronyx-cyrillic/-/blob/master/COPYING":                                                                                              "Cronyx",
	"gitlab.freedesktop.org/xorg/font/misc-cyrillic/-/blob/master/COPYING":                                                                                                "Cronyx",
	"gitlab.freedesktop.org/xorg/font/screen-cyrillic/-/blob/master/COPYING":                                                                                              "Cronyx",
	"gitlab.freedesktop.org/xorg/lib/libx11/-/blob/master/COPYING?ref_type=heads#L138-171":                                                                                "TekHVC",
	"gitlab.freedesktop.org/xorg/lib/libxext/-/blob/master/COPYING?ref_type=heads#L153-162":                                                                               "HPND-doc-sell",
	"gitlab.freedesktop.org/xorg/lib/libxext/-/blob/master/COPYING?ref_type=heads#L185-197":                                                                               "HPND-doc",
	"gitlab.freedesktop.org/xorg/lib/libxinerama/-/blob/cc22c2f60c3862482562955116d5455263b443dc/COPYING#L44-66":                                                          "X11-no-permit-persons",
	"gitlab.freedesktop.org/xorg/lib/libxtst/-/blob/master/COPYING?ref_type=heads#L108-117":                                                                               "HPND-doc-sell",
	"gitlab.freedesktop.org/xorg/lib/libxtst/-/blob/master/COPYING?ref_type=heads#L70-77":                                                                                 "HPND-doc",
	"gitlab.freedesktop.org/xorg/xserver/-/blob/master/COPYING?ref_type=heads#L1781":                                                                                      "HPND-sell-MIT-disclaimer-xserver",
	"gitlab.freedesktop.org/xorg/xserver/-/blob/master/COPYING?ref_type=heads#L239":                                                                                       "DEC-3-Clause",
	"gitlab.freedesktop.org/xorg/xserver/-/blob/master/COPYING?ref_type=heads#L752":                                                                                       "Adobe-Display-PostScript",
	"gitlab.isc.org/isc-projects/bind9/blob/master/COPYRIGHT#L366":                                                                                                        "JPNIC",
	"gitlab.lrz.de/mmix/mmixware/-/blob/master/boilerplate.w":                                                                                                             "MMIXware",
	"gitlab.syncad.com/hive/dhive/-/blob/master/LICENSE":                                                                                                                  "BSD-3-Clause-No-Military-License",
	"gitweb.gentoo.org/repo/gentoo.git/tree/licenses/SGMLUG?id=7d999af4a47bf55e53e54713d98d145f935935c1":                                                                  "SGMLUG-PM",
	"glassfish.java.net/public/CDDL+GPL_1_1.html":                                                                                                                         "CDDL-1.1",
	"graphics.pixar.com/opensubdiv/docs/license.html":                                                                                                                     "Pixar",
	"gridscheduler.sourceforge.net/Gridengine_SISSL_license.html":                                                                                                         "SISSL-1.2",
	"heasarc.gsfc.nasa.gov/docs/software/fitsio/c/f_user/node9.html":                                                                                                      "CFITSIO",
	"heasarc.gsfc.nasa.gov/docs/software/ftools/fv/doc/license.html":                                                                                                      "CFITSIO",
	"helixcommunity.org/content/rpsl":                                                                                                                                     "RPSL-1.0",
	"hstechdocs.helpsystems.com/manuals/globalscape/archive/cuteftp6/open_ssl_license_agreement.htm":                                                                      "OpenSSL-standalone",
	"java.net/projects/javaeetutorial/pages/BerkeleyLicense":                                                                                                              "BSD-3-Clause-No-Nuclear-License-2014",
	"javaee.github.io/glassfish/LICENSE":                                                                                                                                  "CDDL-1.1",
	"jogamp.org/git/?p=gluegen.git;a=blob_plain;f=LICENSE.txt":                                                                                                            "BSD-3-Clause-No-Nuclear-Warranty",
	"joinup.ec.europa.eu/page/eupl-text-11-12":                                                                                                                            "EUPL-1.2",
	"joinup.ec.europa.eu/sites/default/files/custom-page/attachment/2020-03/EUPL-1.2%20EN.txt":                                                                            "EUPL-1.2",
	"joinup.ec.europa.eu/sites/default/files/custom-page/attachment/eupl1.1.-licence-en_0.pdf":                                                                            "EUPL-1.1",
	"joinup.ec.europa.eu/sites/default/files/custom-page/attachment/eupl_v1.2_en.pdf":                                                                                     "EUPL-1.2",
	"joinup.ec.europa.eu/sites/default/files/inline-files/EUPL%20v1_2%20EN(1).txt":                                                                                        "EUPL-1.2",
	"joinup.ec.europa.eu/software/page/eupl/licence-eupl":                                                                                                                 "EUPL-1.1",
	"joinup.ec.europa.eu/svn/lesoll/trunk/italc/lib/src/dsa_key.cpp":                                                                                                      "SSH-short",
	"labs.metacarta.com/license-explanation.html#license":                                                                                                                 "BSD-3-Clause-Clear",
	"landley.net/toybox/license.html":                                                                                                                                     "0BSD",
	"legacy.imatix.com/html/sfl/sfl4.htm#license":                                                                                                                         "iMatix",
	"liballeg.org/license.html#allegro-4-the-giftware-license":                                                                                                            "Giftware",
	"libgd.github.io/manuals/2.3.0/files/license-txt.html":                                                                                                                "GD",
	"library.netapp.com/ecm/ecm_download_file/ECMP1196395":                                                                                                                "OpenSSL-standalone",
	"license.coscl.org.cn/MulanPSL/":                                                                                                                                      "MulanPSL-1.0",
	"license.coscl.org.cn/MulanPSL2":                                                                                                                                      "MulanPSL-2.0",
	"lists.gnu.org/archive/html/autoconf/2012-04/msg00061.html":                                                                                                           "FSFULLRWD",
	"lists.opensource.org/pipermail/license-discuss_lists.opensource.org/2002-November/006304.html":                                                                       "HPND",
	"mariadb.com/bsl11/":                                                                                             "BUSL-1.1",
	"math.nist.gov/tnt/download.html":                                                                                "NIST-PD-TNT",
	"matplotlib.org/stable/project/license.html":                                                                     "PSF-2.0",
	"metacpan.org/pod/Exporter::Tidy#LICENSE":                                                                        "any-OSI",
	"metacpan.org/pod/Net::MQTT::Simple#LICENSE":                                                                     "any-OSI-perl-modules",
	"metacpan.org/pod/Qmail::Deliverable::Client#LICENSE":                                                            "any-OSI-perl-modules",
	"metacpan.org/pod/Time::ParseDate#LICENSE":                                                                       "TPDL",
	"metacpan.org/release/DPARIS/Crypt-Blowfish-2.14/source/COPYRIGHT#L7":                                            "BSD-Systemics-W3Works",
	"metacpan.org/release/DPARIS/Crypt-DES-2.07/source/COPYRIGHT":                                                    "BSD-Systemics",
	"metacpan.org/release/JUERD/Exporter-Tidy-0.09/view/Tidy.pm#LICENSE":                                             "any-OSI-perl-modules",
	"metacpan.org/release/KNOK/File-MMagic-1.30/source/COPYING#L28":                                                  "Spencer-94",
	"metacpan.org/release/NLNETLABS/Net-DNS-SEC-1.22/source/LICENSE":                                                 "HPND-MIT-disclaimer",
	"metacpan.org/release/RJBS/Text-Soundex-3.05/source/Soundex.pm#L3-11":                                            "Soundex",
	"metadata.ftp-master.debian.org/changelogs//main/a/arpwatch/arpwatch_2.1a15-7_copyright":                         "BSD-4-Clause-Shortened",
	"metadata.ftp-master.debian.org/changelogs//main/f/fonts-paratype/fonts-paratype_20181108-4_copyright":           "ParaType-Free-Font-1.3",
	"metadata.ftp-master.debian.org/changelogs//main/x/xzoom/xzoom_0.3-27_copyright":                                 "xzoom",
	"mirror.las.iastate.edu/tex-archive/graphics/metapost/contrib/macros/slideshow/slideshow.mp":                     "McPhee-slideshow",
	"mirrors.ctan.org/macros/latex/contrib/ulem/README":                                                              "ulem",
	"mirrors.ctan.org/macros/latex/contrib/version/version.sty":                                                      "magaz",
	"mirrors.nic.cz/tex-archive/macros/latex/contrib/fwlw/README":                                                    "fwlw",
	"mirrors.nic.cz/tex-archive/macros/latex/contrib/magaz/magaz.tex":                                                "magaz",
	"mod-buildcraft.com/MMPL-1.0.txt":                                                                                "MMPL-1.0.1",
	"old.koalateam.com/jackaroo/OPL_1_0.TXT":                                                                         "OPL-1.0",
	"old.zope.org/Resources/License/ZPL-1.1":                                                                         "ZPL-1.1",
	"old.zope.org/Resources/License/ZPL-2.0":                                                                         "ZPL-2.0",
	"old.zope.org/Resources/ZPL/":                                                                                    "ZPL-2.1",
	"open.canada.ca/en/open-government-licence-canada":                                                               "OGL-Canada-2.0",
	"opencontent.org/openpub/":                                                                                       "OPUBL-1.0",
	"opendatacommons.org/licenses/by/1.0/":                                                                           "ODC-By-1.0",
	"opendatacommons.org/licenses/odbl/1-0/":                                                                         "ODbL-1.0",
	"opendatacommons.org/licenses/pddl/":                                                                             "PDDL-1.0",
	"opendatacommons.org/licenses/pddl/1.0/":                                                                         "PDDL-1.0",
	"openlogisticsfoundation.org/licenses/":                                                                          "OLFL-1.3",
	"openmdw.ai/license/":                                                                                            "OpenMDW-1.0",
	"opensource.apple.com/source/JBoss/JBoss-737/jboss-all/jetty/src/main/org/mortbay/util/UnixCrypt.java.auto.html": "UnixCrypt",
	"opensource.apple.com/source/mDNSResponder/mDNSResponder-320.10/mDNSPosix/nss_ReadMe.txt":                        "NICTA-1.0",
	"opensource.linux-mirror.org/licenses/afl-1.1.txt":                                                               "AFL-1.1",
	"opensource.linux-mirror.org/licenses/afl-1.2.txt":                                                               "AFL-1.2",
	"opensource.linux-mirror.org/licenses/afl-2.1.txt":                                                               "AFL-2.1",
	"opensource.org/license/apache-2-0":                                                                              "Apache-2.0",
	"opensource.org/license/mit/":                                                                                    "MIT",
	"opensource.org/license/olfl-1-3/":                                                                               "OLFL-1.3",
	"opensource.org/license/osc-license-1-0":                                                                         "OSC-1.0",
	"opensource.org/licenses/0BSD":                                                                                   "0BSD",
	"opensource.org/licenses/AGPL-3.0":                                                                               "AGPL-3.0-or-later",
	"opensource.org/licenses/APL-1.0":                                                                                "APL-1.0",
	"opensource.org/licenses/Apache-1.1":                                                                             "Apache-1.1",
	"opensource.org/licenses/Apache-2.0":                                                                             "Apache-2.0",
	"opensource.org/licenses/Artistic-1.0":                                                                           "Artistic-1.0-cl8",
	"opensource.org/licenses/BSD-2-Clause":                                                                           "BSD-2-Clause",
	"opensource.org/licenses/BSD-3-Clause":                                                                           "BSD-3-Clause",
	"opensource.org/licenses/BSDplusPatent":                                                                          "BSD-2-Clause-Patent",
	"opensource.org/licenses/BSL-1.0":                                                                                "BSL-1.0",
	"opensource.org/licenses/CAL-1.0":                                                                                "CAL-1.0-Combined-Work-Exception",
	"opensource.org/licenses/CATOSL-1.1":                                                                             "CATOSL-1.1",
	"opensource.org/licenses/CNRI-Python":                                                                            "CNRI-Python",
	"opensource.org/licenses/CPAL-1.0":                                                                               "CPAL-1.0",
	"opensource.org/licenses/CPL-1.0":                                                                                "CPL-1.0",
	"opensource.org/licenses/CUA-OPL-1.0":                                                                            "CUA-OPL-1.0",
	"opensource.org/licenses/ECL-1.0":                                                                                "ECL-1.0",
	"opensource.org/licenses/ECL-2.0":                                                                                "ECL-2.0",
	"opensource.org/licenses/EFL-1.0":                                                                                "EFL-1.0",
	"opensource.org/licenses/EFL-2.0":                                                                                "EFL-2.0",
	"opensource.org/licenses/EPL-1.0":                                                                                "EPL-1.0",
	"opensource.org/licenses/EUDatagrid":                                                                             "EUDatagrid",
	"opensource.org/licenses/EUPL-1.1":                                                                               "EUPL-1.1",
	"opensource.org/licenses/EUPL-1.2":                                                                               "EUPL-1.2",
	"opensource.org/licenses/Entessa":                                                                                "Entessa",
	"opensource.org/licenses/Fair":                                                                                   "Fair",
	"opensource.org/licenses/Frameworx-1.0":                                                                          "Frameworx-1.0",
	"opensource.org/licenses/GPL-2.0":                                                                                "GPL-2.0-or-later",
	"opensource.org/licenses/GPL-3.0":                                                                                "GPL-3.0-or-later",
	"opensource.org/licenses/HPND":                                                                                   "HPND",
	"opensource.org/licenses/IPA":                                                                                    "IPA",
	"opensource.org/licenses/IPL-1.0":                                                                                "IPL-1.0",
	"opensource.org/licenses/ISC":                                                                                    "ISC",
	"opensource.org/licenses/Intel":                                                                                  "Intel",
	"opensource.org/licenses/LGPL-2.1":                                                                               "LGPL-2.1-or-later",
	"opensource.org/licenses/LGPL-3.0":                                                                               "LGPL-3.0-or-later",
	"opensource.org/licenses/LPL-1.0":                                                                                "LPL-1.0",
	"opensource.org/licenses/LPL-1.02":                                                                               "LPL-1.02",
	"opensource.org/licenses/LPPL-1.3c":                                                                              "LPPL-1.3c",
	"opensource.org/licenses/LiLiQ-P-1.1":                                                                            "LiLiQ-P-1.1",
	"opensource.org/licenses/LiLiQ-R-1.1":                                                                            "LiLiQ-R-1.1",
	"opensource.org/licenses/LiLiQ-Rplus-1.1":                                                                        "LiLiQ-Rplus-1.1",
	"opensource.org/licenses/MIT":                                                                                    "MIT",
	"opensource.org/licenses/MPL-1.0":                                                                                "MPL-1.0",
	"opensource.org/licenses/MPL-1.1":                                                                                "MPL-1.1",
	"opensource.org/licenses/MPL-2.0":                                                                                "MPL-2.0-no-copyleft-exception",
	"opensource.org/licenses/MS-PL":                                                                                  "MS-PL",
	"opensource.org/licenses/MS-RL":                                                                                  "MS-RL",
	"opensource.org/licenses/MirOS":                                                                                  "MirOS",
	"opensource.org/licenses/Motosoto":                                                                               "Motosoto",
	"opensource.org/licenses/Multics":                                                                                "Multics",
	"opensource.org/licenses/NASA-1.3":                                                                               "NASA-1.3",
	"opensource.org/licenses/NCSA":                                                                                   "NCSA",
	"opensource.org/licenses/NGPL":                                                                                   "NGPL",
	"opensource.org/licenses/NOSL3.0":                                                                                "NPOSL-3.0",
	"opensource.org/licenses/NTP":                                                                                    "NTP",
	"opensource.org/licenses/Naumen":                                                                                 "Naumen",
	"opensource.org/licenses/OCLC-2.0":                                                                               "OCLC-2.0",
	"opensource.org/licenses/OFL-1.1":                                                                                "OFL-1.1-no-RFN",
	"opensource.org/licenses/OGTSL":                                                                                  "OGTSL",
	"opensource.org/licenses/OPL-2.1":                                                                                "OSET-PL-2.1",
	"opensource.org/licenses/OSL-1.0":                                                                                "OSL-1.0",
	"opensource.org/licenses/OSL-2.1":                                                                                "OSL-2.1",
	"opensource.org/licenses/OSL-3.0":                                                                                "OSL-3.0",
	"opensource.org/licenses/PHP-3.0":                                                                                "PHP-3.0",
	"opensource.org/licenses/PostgreSQL":                                                                             "PostgreSQL",
	"opensource.org/licenses/Python-2.0":                                                                             "Python-2.0",
	"opensource.org/licenses/QPL-1.0":                                                                                "QPL-1.0",
	"opensource.org/licenses/RPL-1.1":                                                                                "RPL-1.1",
	"opensource.org/licenses/RPL-1.5":                                                                                "RPL-1.5",
	"opensource.org/licenses/RPSL-1.0":                                                                               "RPSL-1.0",
	"opensource.org/licenses/RSCPL":                                                                                  "RSCPL",
	"opensource.org/licenses/SISSL":                                                                                  "SISSL",
	"opensource.org/licenses/SPL-1.0":                                                                                "SPL-1.0",
	"opensource.org/licenses/SimPL-2.0":                                                                              "SimPL-2.0",
	"opensource.org/licenses/Sleepycat":                                                                              "Sleepycat",
	"opensource.org/licenses/UCL-1.0":                                                                                "UCL-1.0",
	"opensource.org/licenses/UPL":                                                                                    "UPL-1.0",
	"opensource.org/licenses/VSL-1.0":                                                                                "VSL-1.0",
	"opensource.org/licenses/W3C":                                                                                    "W3C",
	"opensource.org/licenses/Watcom-1.0":                                                                             "Watcom-1.0",
	"opensource.org/licenses/Xnet":                                                                                   "Xnet",
	"opensource.org/licenses/ZPL-2.0":                                                                                "ZPL-2.0",
	"opensource.org/licenses/Zlib":                                                                                   "Zlib",
	"opensource.org/licenses/afl-3.0":                                                                                "AFL-3.0",
	"opensource.org/licenses/artistic-license-2.0":                                                                   "Artistic-2.0",
	"opensource.org/licenses/attribution":                                                                            "AAL",
	"opensource.org/licenses/cddl1":                                                                                  "CDDL-1.0",
	"opensource.org/licenses/nokia":                                                                                  "Nokia",
	"oss.sgi.com/projects/FreeB/":                                                                                    "SGI-B-1.1",
	"oss.sgi.com/projects/FreeB/SGIFreeSWLicB.1.0.html":                                                              "SGI-B-1.0",
	"oss.sgi.com/projects/FreeB/SGIFreeSWLicB.2.0.pdf":                                                               "SGI-B-2.0",
	"otm.illinois.edu/uiuc_openSource":                                                                               "NCSA",
	"pages.cs.wisc.edu/~ghost/doc/AFPL/6.01/Public.htm":                                                              "Aladdin",
	"paritylicense.com/versions/6.0.0.html":                                                                          "Parity-6.0.0",
	"paritylicense.com/versions/7.0.0.html":                                                                          "Parity-7.0.0",
	"people.freebsd.org/~ivoras/wine/patch-wine-nvidia.sh":                                                           "BSD-2-Clause-Views",
	"people.freebsd.org/~phk/":                                                                                       "Beerware",
	"people.mpi-inf.mpg.de/~uwe/misc/uw-ttyp0/":                                                                      "TTYP0",
	"pirlwww.lpl.arizona.edu/resources/guide/software/PerlTk/Tixlic.html":                                            "MIT-Modern-Variant",
	"plan9.bell-labs.com/plan9/license.html":                                                                         "LPL-1.02",
	"polyformproject.org/licenses/noncommercial/1.0.0":                                                               "PolyForm-Noncommercial-1.0.0",
	"polyformproject.org/licenses/small-business/1.0.0":                                                              "PolyForm-Small-Business-1.0.0",
	"primates.ximian.com/~flucifredi/man/man-1.6g.tar.gz":                                                            "man2html",
	"projects.eclipse.org/license/epl-2.0":                                                                           "EPL-2.0",
	"ptolemy.berkeley.edu/copyright.htm":                                                                             "MIT-Modern-Variant",
	"public.dhe.ibm.com/aix/freeSoftware/aixtoolbox/LICENSES/unRAR.txt":                                              "UnRAR",
	"raw.githubusercontent.com/DISIC/politique-de-contribution-open-source/master/LICENSE":                           "etalab-2.0",
	"raw.githubusercontent.com/GNOME/libxml2/4c2e7c651f6c2f0d1a74f350cbda95f7df3e7017/hash.c":                        "ISC-Veillard",
	"raw.githubusercontent.com/NTIA/itm/refs/heads/master/LICENSE.md":                                                "NTIA-PD",
	"raw.githubusercontent.com/NTIA/scos-sensor/refs/heads/master/LICENSE.md":                                        "NTIA-PD",
	"raw.githubusercontent.com/OpenMDW/OpenMDW/refs/heads/main/1.0/LICENSE.openmdw":                                  "OpenMDW-1.0",
	"raw.githubusercontent.com/blackhole89/notekit/master/data/fonts/Charter%20license.txt":                          "Bitstream-Charter",
	"rc.quest.com/topics/openssh/license.php#tcpwrappers":                                                            "TCP-wrappers",
	"research.cs.wisc.edu/condor/license.html#condor":                                                                "Condor-1.1",
	"research.scea.com/scea_shared_source_license.html":                                                              "SCEA",
	"romanrm.net/mit-zero":                                                                                           "MIT-0",
	"sam.zoy.org/wtfpl/COPYING":                                                                                      "WTFPL",
	"scripts.sil.org/cms/scripts/page.php?item_id=OFL10_web":                                                         "OFL-1.0-no-RFN",
	"scripts.sil.org/cms/scripts/page.php?item_id=OFL_web":                                                           "OFL-1.1-no-RFN",
	"slicer.org/LICENSE":                                                                                             "3D-Slicer-1.0",
	"solderpad.org/licenses/SHL-0.5/":                                                                                "SHL-0.5",
	"solderpad.org/licenses/SHL-0.51/":                                                                               "SHL-0.51",
	"source.icu-project.org/repos/icu/icu/trunk/license.html":                                                        "ICU",
	"sourceforge.net/p/buddy/gitcode/ci/master/tree/README":                                                          "Buddy",
	"sourceforge.net/p/ctrio/git/ci/master/tree/README":                                                              "ISC-Veillard",
	"sourceforge.net/p/mcj/xfig/ci/master/tree/src/Makefile.am":                                                      "Xfig",
	"sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/converter/other/pnmtorle.c":                                "URT-RLE",
	"sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/converter/other/rletopnm.c":                                "URT-RLE",
	"sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/converter/ppm/ppmtompeg/jrevdct.c#l1189":                   "MPEG-SSG",
	"sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/editor/pnmstitch.c#l2":                                     "pnmstitch",
	"sourceforge.net/p/netpbm/code/HEAD/tree/super_stable/netpbm.c#l8":                                               "HPND-Pbmplus",
	"sourceforge.net/p/sbcl/sbcl/ci/master/tree/src/code/loop.lisp":                                                  "LOOP",
	"sourceforge.net/p/trustedqsl/tqsl/ci/master/tree/LICENSE.txt":                                                   "TrustedQSL",
	"sourceforge.net/p/xmedcon/code/ci/master/tree/libs/dicom/README":                                                "OFFIS",
	"sourceforge.net/p/xmedcon/code/ci/master/tree/libs/ljpg/":                                                       "IJG-short",
	"sourceforge.net/projects/sevenzip/files/LZMA%20SDK/":                                                            "LZMA-SDK-9.22",
	"sources.debian.org/copyright/license/debianutils/4.11.2/":                                                       "SMAIL-GPL",
	"sources.debian.org/src/openmpi/4.1.0-10/ompi/debuggers/msgq_interface.h/?hl=19#L19":                             "mpi-permissive",
	"sources.gentoo.org/cgi-bin/viewvc.cgi/gentoo-x86/licenses/BitTorrent?r1=1.1&r2=1.1.1.1&diff_format=s":           "BitTorrent-1.0",
	"sourceware.org/bzip2/1.0.5/bzip2-manual-1.0.5.html":                                                             "bzip2-1.0.6",
	"sourceware.org/cgit/binutils-gdb/tree/include/coff/sym.h#n11":                                                   "MIPS",
	"sourceware.org/cgit/binutils-gdb/tree/include/coff/symconst.h#n11":                                              "ThirdEye",
	"sourceware.org/cgit/valgrind/tree/mpi/libmpiwrap.c":                                                             "bzip2-1.0.6",
	"sourceware.org/git/?p=binutils-gdb.git;a=blob;f=libiberty/strcasecmp.c;h=131d81c2ce7881fa48c363dc5bf5fb302c61ce0b;hb=HEAD":                  "BSD-4.3RENO",
	"sourceware.org/git/?p=binutils-gdb.git;a=blob;f=readline/readline/support/wcwidth.c;h=0f5ec995796f4813abbcf4972aec0378ab74722a;hb=HEAD#l55": "HPND-Markus-Kuhn",
	"sourceware.org/git/?p=bzip2.git;a=blob;f=LICENSE;hb=bzip2-1.0.6":                                                                            "bzip2-1.0.6",
	"sourceware.org/git/?p=glibc.git;a=blob;f=LICENSES;h=530893b1dc9ea00755603c68fb36bd4fc38a7be8;hb=HEAD#l207":                                  "Inner-Net-2.0",
	"sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/machine/hppa/memchr.S;h=1cca3e5e8867aa4bffef1f75a5c1bba25c0c441e;hb=HEAD#l2":   "HP-1986",
	"sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/machine/i960/memcpy.S;hb=HEAD":                                                 "HPND-Intel",
	"sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/misc/fini.c;hb=HEAD":                                                           "HPND-merchantability-variant",
	"sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/stdlib/mprec.h;hb=HEAD":                                                        "dtoa",
	"sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/string/strsignal.c;hb=HEAD#l35":                                                "OAR",
	"sourceware.org/git/?p=newlib-cygwin.git;a=blob;f=newlib/libc/sys/a29khif/_close.S;h=04f52ae00de1dafbd9055ad8d73c5c697a3aae7f;hb=HEAD":       "AMD-newlib",
	"sqlite.org/src/artifact/df5091916dbb40e6":                                                                                                   "blessing",
	"svnkit.com/license.html": "TMate",
	"svnweb.freebsd.org/base/head/include/ifaddrs.h?revision=326823":                                                      "BSD-1-Clause",
	"tahoe-lafs.org/trac/tahoe-lafs/browser/trunk/COPYING.TGPPL.rst":                                                      "TGPPL-1.0",
	"ti.arc.nasa.gov/opensource/nosa/":                                                                                    "NASA-1.3",
	"trac.enlightenment.org/e/browser/trunk/imlib2/COPYING":                                                               "Imlib2",
	"ubuntu.com/legal/font-licence":                                                                                       "Ubuntu-font-1.0",
	"unlicense.org/":                                                                                                      "Unlicense",
	"vimdoc.sourceforge.net/htmldoc/uganda.html":                                                                          "Vim",
	"wayback.archive.org/web/20021004124254/http://www.opensource.org/licenses/academic.php":                              "AFL-1.1",
	"wayback.archive.org/web/20021204204652/http://www.opensource.org/licenses/academic.php":                              "AFL-1.2",
	"wayback.archive.org/web/20060715140826/http://www.risource.org/RPL/RPL-1.0A.shtml":                                   "RSCPL",
	"wayback.archive.org/web/20060924134533/http://www.opensource.org/licenses/afl-2.0.txt":                               "AFL-2.0",
	"web.archive.org/web/20041020171434/http://www.rosenlaw.com/osl2.0.html":                                              "OSL-2.0",
	"web.archive.org/web/20050212003940/http://www.rosenlaw.com/osl21.htm":                                                "OSL-2.1",
	"web.archive.org/web/20060319014854/http://info.borland.com/devsupport/interbase/opensource/IPL.html":                 "Interbase-1.0",
	"web.archive.org/web/20080207013128/http://www.gnome.org/fonts/":                                                      "Bitstream-Vera",
	"web.archive.org/web/20100302225219/http://www.zimbra.com/license/zimbra-public-license-1-3.html":                     "Zimbra-1.3",
	"web.archive.org/web/20111123062036/http://research.cs.wisc.edu/condor/license.html#condor":                           "Condor-1.1",
	"web.archive.org/web/20120101081418/http://rosenlaw.com:80/OSL3.0.htm":                                                "OSL-3.0",
	"web.archive.org/web/20130517195954/http://www.zend.com/license/2_00.txt":                                             "Zend-2.0",
	"web.archive.org/web/20140704074106/http://www.unicode.org/copyright.html":                                            "Unicode-TOU",
	"web.archive.org/web/20150926120323/http://fairlicense.org/":                                                          "Fair",
	"web.archive.org/web/20151224134844/http://unicode.org/copyright.html":                                                "Unicode-DFS-2015",
	"web.archive.org/web/20160322142305/https://www.sendmail.com/pdfs/open_source/sendmail_license.pdf":                   "Sendmail",
	"web.archive.org/web/20160330173339/https://swarm.workshop.perforce.com/files/guest/perforce_software/jam/src/README": "Jam",
	"web.archive.org/web/20160823201924/http://www.unicode.org/copyright.html#License":                                    "Unicode-DFS-2016",
	"web.archive.org/web/20161209023955/http://www.paratype.ru/public/pt_openlicense_eng.asp":                             "ParaType-Free-Font-1.3",
	"web.archive.org/web/20181003101040/https://www.proofpoint.com/sites/default/files/sendmail-license.pdf":              "Sendmail-8.23",
	"web.mit.edu/freebsd/head/lib/libutil/login_ok.3":                                                                     "libutil-David-Nugent",
	"web.mit.edu/kerberos/krb5-1.21/doc/mitK5license.html":                                                                "OpenVision",
	"web.mit.edu/kolya/.f/root/athena.mit.edu/sipb.mit.edu/project/openssh/OldFiles/src/openssh-2.9.9p2/ssh-add.1":        "SSH-short",
	"web.mit.edu/network/isakmp/nrllicense.html":                                                                          "NRL",
	"wiki.p2pfoundation.net/Peer_Production_License":                                                                      "PPL",
	"wordnet.princeton.edu/license-and-commercial-use":                                                                    "WordNet",
	"www-igm.univ-mlv.fr/~unitex/lgpllr.html":                                                                             "LGPLLR",
	"www.7-zip.org/sdk.html":                                        "LZMA-SDK-9.22",
	"www.affero.org/oagpl.html":                                     "AGPL-1.0-or-later",
	"www.antlr2.org/license.html":                                   "ANTLR-PD-fallback",
	"www.apache.org/licenses/LICENSE-1.0":                           "Apache-1.0",
	"www.apache.org/licenses/LICENSE-2.0":                           "Apache-2.0",
	"www.boost.org/LICENSE_1_0.txt":                                 "BSL-1.0",
	"www.boost.org/doc/libs/1_35_0/doc/html/jam.html":               "Jam",
	"www.cecill.info/licences/Licence_CeCILL-B_V1-en.html":          "CECILL-B",
	"www.cecill.info/licences/Licence_CeCILL-C_V1-en.html":          "CECILL-C",
	"www.cecill.info/licences/Licence_CeCILL_V1-fr.html":            "CECILL-1.0",
	"www.cecill.info/licences/Licence_CeCILL_V1.1-US.html":          "CECILL-1.1",
	"www.cecill.info/licences/Licence_CeCILL_V2-en.html":            "CECILL-2.0",
	"www.cecill.info/licences/Licence_CeCILL_V2.1-en.html":          "CECILL-2.1",
	"www.cl.cam.ac.uk/~mgk25/ucs/wcwidth.c":                         "HPND-Markus-Kuhn",
	"www.codeproject.com/info/cpol10.aspx":                          "CPOL-1.02",
	"www.cs.auckland.ac.nz/~pgut001/dumpasn1.c":                     "Gutmann",
	"www.cs.cmu.edu/~410/licenses.html":                             "CMU-Mach",
	"www.cs.fsu.edu/~engelen/license.html":                          "gSOAP-1.3b",
	"www.cs.wustl.edu/~schmidt/ACE-copying.html":                    "DOC",
	"www.ctan.org/license/opl":                                      "OPUBL-1.0",
	"www.cve.org/Legal/TermsOfUse":                                  "cve-tou",
	"www.db.net/downloads/wwl+db-1.3.tgz":                           "wwl",
	"www.debian.org/opl":                                            "OPUBL-1.0",
	"www.dipp.nrw.de/d-fsl/index_html/lizenzen/de/D-FSL-1_0_de.txt": "D-FSL-1.0",
	"www.dipp.nrw.de/d-fsl/index_html/lizenzen/en/D-FSL-1_0_en.txt": "D-FSL-1.0",
	"www.dipp.nrw.de/d-fsl/lizenzen/":                               "D-FSL-1.0",
	"www.docbook.org/xml/5.0/docbook-5.0.zip":                       "DocBook-Stylesheet",
	"www.docbook.org/xml/simple/1.1/docbook-simple-1.1.zip":         "DocBook-DTD",
	"www.dre.vanderbilt.edu/~schmidt/ACE-copying.html":              "DOC",
	"www.ece.uvic.ca/~mdadams/jasper/LICENSE":                       "JasPer-2.0",
	"www.eclipse.org/legal/epl-2.0":                                 "EPL-2.0",
	"www.eclipse.org/legal/epl-v10.html":                            "EPL-1.0",
	"www.eclipse.org/legal/epl-v20.html":                            "EPL-2.0",
	"www.eclipse.org/org/documents/edl-v10.php":                     "BSD-3-Clause",
	"www.egenix.com/products/eGenix.com-Public-License-1.1.0.pdf":   "eGenix",
	"www.eiffel-nice.org/license/eiffel-forum-license-2.html":       "EFL-2.0",
	"www.eiffel-nice.org/license/forum.txt":                         "EFL-1.0",
	"www.elastic.co/licensing/elastic-license":                      "Elastic-2.0",
	"www.erlang.org/EPLICENSE":                                      "ErlPL-1.1",
	"www.faqs.org/rfcs/rfc1321.html":                                "RSA-MD",
	"www.forge.gouv.qc.ca/participez/licence-logicielle/licence-libre-du-quebec-liliq-en-francais/licence-libre-du-quebec-reciprocite-forte-liliq-r-v1-1/": "LiLiQ-Rplus-1.1",
	"www.forge.gouv.qc.ca/participez/licence-logicielle/licence-libre-du-quebec-liliq-en-francais/licence-libre-du-quebec-reciprocite-liliq-r-v1-1/":       "LiLiQ-R-1.1",
	"www.freebsd.org/copyright/freebsd-doc-license/":                                      "FreeBSD-DOC",
	"www.freebsd.org/copyright/freebsd-license.html":                                      "BSD-2-Clause-Views",
	"www.freebsd.org/copyright/license.html":                                              "BSD-4-Clause-UC",
	"www.geuz.org/gl2ps/COPYING.GL2PS":                                                    "GL2PS",
	"www.gnu.org/licenses/agpl.txt":                                                       "AGPL-3.0-or-later",
	"www.gnu.org/licenses/fdl-1.3.txt":                                                    "GFDL-1.3-or-later",
	"www.gnu.org/licenses/gpl-3.0-standalone.html":                                        "GPL-3.0-or-later",
	"www.gnu.org/licenses/lgpl+gpl-3.0.txt":                                               "LGPL-3.0-or-later",
	"www.gnu.org/licenses/lgpl-3.0-standalone.html":                                       "LGPL-3.0-or-later",
	"www.gnu.org/licenses/license-list.html#ACDL":                                         "CDL-1.0",
	"www.gnu.org/licenses/old-licenses/fdl-1.1.txt":                                       "GFDL-1.1-or-later",
	"www.gnu.org/licenses/old-licenses/fdl-1.2.txt":                                       "GFDL-1.2-or-later",
	"www.gnu.org/licenses/old-licenses/gpl-1.0-standalone.html":                           "GPL-1.0-or-later",
	"www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html":                           "GPL-2.0-or-later",
	"www.gnu.org/licenses/old-licenses/gpl-2.0.txt":                                       "GPL-2.0-only",
	"www.gnu.org/licenses/old-licenses/lgpl-2.0-standalone.html":                          "LGPL-2.0-or-later",
	"www.gnu.org/licenses/old-licenses/lgpl-2.1-standalone.html":                          "LGPL-2.1-or-later",
	"www.gnu.org/licenses/old-licenses/lgpl-2.1.html":                                     "LGPL-2.1-or-later",
	"www.gnu.org/prep/maintain/html_node/License-Notices-for-Other-Files.html":            "FSFAP",
	"www.govdata.de/dl-de/by-2-0":                                                         "DL-DE-BY-2.0",
	"www.govdata.de/dl-de/zero-2-0":                                                       "DL-DE-ZERO-2.0",
	"www.hbz-nrw.de/produkte/open-access/lizenzen/dfsl":                                   "D-FSL-1.0",
	"www.hbz-nrw.de/produkte/open-access/lizenzen/dfsl/D-FSL-1_0_de.txt/at_download/file": "D-FSL-1.0",
	"www.hbz-nrw.de/produkte/open-access/lizenzen/dfsl/D-FSL-1_0_en.txt/at_download/file": "D-FSL-1.0",
	"www.hbz-nrw.de/produkte/open-access/lizenzen/dfsl/deutsche-freie-software-lizenz":    "D-FSL-1.0",
	"www.hbz-nrw.de/produkte/open-access/lizenzen/dfsl/german-free-software-license":      "D-FSL-1.0",
	"www.iausofa.org/tandc.html":                                                          "SOFA",
	"www.iec.ch/CCv1":                                                                     "IEC-Code-Components-EULA",
	"www.iec.ch/copyright":                                                                "IEC-Code-Components-EULA",
	"www.iec.ch/webstore/custserv/pdf/CC-EULA.pdf":                                        "IEC-Code-Components-EULA",
	"www.ietf.org/rfc/rfc1952.txt":                                                        "LPD-document",
	"www.imagemagick.org/script/license.php":                                              "ImageMagick",
	"www.inet.no/dante/LICENSE":                                                           "BSD-Inferno-Nettverk",
	"www.info-zip.org/license.html":                                                       "Info-ZIP",
	"www.isc.org/downloads/software-support-policy/isc-license/":                          "ISC",
	"www.isc.org/licenses/":                                                               "ISC",
	"www.itu.int/ITU-T/formal-language/itu-t/t/t173/1997/ISOMHEG-sir.html":                "ISO-permission",
	"www.jpl.nasa.gov/jpl-image-use-policy":                                               "JPL-image",
	"www.json.org/license.html":                                                           "JSON",
	"www.jython.org/license.html":                                                         "CNRI-Jython",
	"www.kermitproject.org/ck90.html#source":                                              "HPND-export-US",
	"www.kernel.org/doc/man-pages/licenses.html":                                          "Linux-man-pages-copyleft",
	"www.latex-project.org/lppl/lppl-1-0.txt":                                             "LPPL-1.0",
	"www.latex-project.org/lppl/lppl-1-1.txt":                                             "LPPL-1.1",
	"www.latex-project.org/lppl/lppl-1-2.txt":                                             "LPPL-1.2",
	"www.latex-project.org/lppl/lppl-1-3a.txt":                                            "LPPL-1.3a",
	"www.latex-project.org/lppl/lppl-1-3c.txt":                                            "LPPL-1.3c",
	"www.lemis.com/grog/UNIX/ancient-source-all.pdf":                                      "Caldera",
	"www.libpng.org/pub/png/src/libpng-LICENSE.txt":                                       "libpng-2.0",
	"www.mail-archive.com/debian-bugs-rc@lists.debian.org/msg11494.html":                  "Symlinks",
	"www.mcs.anl.gov/research/projects/openpbs/PBS_License.txt":                           "OpenPBS-2.3",
	"www.microsoft.com/opensource/licenses.mspx":                                          "MS-RL",
	"www.mongodb.com/licensing/server-side-public-license":                                "SSPL-1.0",
	"www.mozilla.org/MPL/2.0/":                                                            "MPL-2.0-no-copyleft-exception",
	"www.mozilla.org/MPL/MPL-1.0.html":                                                    "MPL-1.0",
	"www.mozilla.org/MPL/MPL-1.1.html":                                                    "MPL-1.1",
	"www.mozilla.org/MPL/NPL/1.0/":                                                        "NPL-1.0",
	"www.mozilla.org/MPL/NPL/1.1/":                                                        "NPL-1.1",
	"www.mssl.ucl.ac.uk/~mcrw/src/20050920/proto.h":                                       "Cornell-Lossless-JPEG",
	"www.nationalarchives.gov.uk/doc/non-commercial-government-licence/version/2/":        "NCGL-UK-2.0",
	"www.nationalarchives.gov.uk/doc/open-government-licence/version/1/":                  "OGL-UK-1.0",
	"www.nationalarchives.gov.uk/doc/open-government-licence/version/2/":                  "OGL-UK-2.0",
	"www.nationalarchives.gov.uk/doc/open-government-licence/version/3/":                  "OGL-UK-3.0",
	"www.ncftp.com/ncftp/doc/LICENSE.txt":                                                 "ClArtistic",
	"www.netbsd.org/about/redistribution.html#default":                                    "BSD-2-Clause",
	"www.netlib.org/lapack/LICENSE.txt":                                                   "BSD-3-Clause-Open-MPI",
	"www.netlib.org/minpack/disclaimer":                                                   "Minpack",
	"www.networkcultures.org/_uploads/%233notebook_telekommunist.pdf":                     "PPL",
	"www.oclc.org/research/activities/software/license/v2final.htm":                       "OCLC-2.0",
	"www.ogc.org/ogc/software/1.0":                                                        "OGC-1.0",
	"www.ohwr.org/project/cernohl/wikis/Documents/CERN-OHL-version-2":                     "CERN-OHL-W-2.0",
	"www.ohwr.org/project/licenses/wikis/cern-ohl-v1.1":                                   "CERN-OHL-1.1",
	"www.ohwr.org/project/licenses/wikis/cern-ohl-v1.2":                                   "CERN-OHL-1.2",
	"www.open-mpi.org/community/license.php":                                              "BSD-3-Clause-Open-MPI",
	"www.opencascade.com/content/occt-public-license":                                     "OCCT-PL",
	"www.opendatacommons.org/licenses/odbl/1.0/":                                          "ODbL-1.0",
	"www.opengroup.org/testing/downloads/The_Open_Group_TSL.txt":                          "OGTSL",
	"www.openhub.net/licenses/mslpl":                                                      "MS-LPL",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=1cae062821881f41b73012ba816434897abf4205": "OLDAP-2.6",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=37b4b3f6cc4bf34e1d3dec61e69914b9819d8894": "NBPL-1.0",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=42b0383c50c299977b5893ee695cf4e486fb0dc7": "OLDAP-1.2",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=470b0c18ec67621c85881b2733057fecf4a1acc3": "OLDAP-2.2",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=47c2415c1df81556eeb39be6cad458ef87c534a2": "OLDAP-2.7",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=4bc786f34b50aa301be6f5600f58a980070f481e": "OLDAP-2.2.1",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=6852b9d90022e8593c98205413380536b1b5a7cf": "OLDAP-2.5",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=806557a5ad59804ef3a44d5abfbe91d706b0791f": "OLDAP-1.1",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=b0d176738e96a0d3b9f85cb51e140a86f21be715": "OLDAP-2.1",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=b6d68acd14e51ca3aab4428bf26522aa74873f0e": "OLDAP-2.0.1",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=c9f95c2f3f2ffb5e0ae55fe7388af75547660941": "OLDAP-1.4",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=cbf50f4e1185a21abd4c0a54d3f4341fe28f36ea": "OLDAP-2.0",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=cd1284c4a91a8a380d904eee68d1583f989ed386": "OLDAP-2.4",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=d32cf54a32d581ab475d23c810b0a7fbaf8d63c3": "OLDAP-2.3",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=df2cc1e21eb7c160695f5b7cffd6296c151ba188": "OLDAP-2.2.2",
	"www.openldap.org/devel/gitweb.cgi?p=openldap.git;a=blob;f=LICENSE;hb=e5f8117f0ce088d0bd7a8e18ddf37eaa40eb09b1": "OLDAP-1.3",
	"www.openldap.org/software/release/license.html":                                                                "OLDAP-2.8",
	"www.openoffice.org/licenses/sissl_license.html":                                                                "SISSL",
	"www.opensource.apple.com/cdl/":                                                                      "CDL-1.0",
	"www.opensource.apple.com/license/apsl/":                                                             "APSL-2.0",
	"www.opensource.apple.com/source/IOSerialFamily/IOSerialFamily-7/APPLE_LICENSE":                      "APSL-1.1",
	"www.opensource.apple.com/source/tcl/tcl-5/tcl/generic/regfronts.c":                                  "Spencer-99",
	"www.opensource.org/licenses/EPL-2.0":                                                                "EPL-2.0",
	"www.openssl.org/source/license.html":                                                                "OpenSSL",
	"www.osetfoundation.org/public-license":                                                              "OSET-PL-2.1",
	"www.parliament.uk/site-information/copyright-parliament/open-parliament-licence/":                   "OPL-UK-3.0",
	"www.perlfoundation.org/artistic-license-20.html":                                                    "Artistic-2.0",
	"www.perlfoundation.org/artistic_license_2_0":                                                        "Artistic-2.0",
	"www.php.net/license/3_0.txt":                                                                        "PHP-3.0",
	"www.php.net/license/3_01.txt":                                                                       "PHP-3.01",
	"www.postgresql.org/about/licence":                                                                   "PostgreSQL",
	"www.proofpoint.com/sites/default/files/sendmail-license.pdf":                                        "Sendmail-8.23",
	"www.python.org/download/releases/1.6.1/download_win/":                                               "CNRI-Python-GPL-Compatible",
	"www.python.org/download/releases/2.0.1/license/":                                                    "Python-2.0.1",
	"www.rosenlaw.com/AFL3.0.htm":                                                                        "AFL-3.0",
	"www.ruby-lang.org/en/about/license.txt":                                                             "Ruby",
	"www.samurajdata.se/opensource/mirror/licenses/apsl.php":                                             "APSL-1.2",
	"www.saxproject.org/copying.html":                                                                    "SAX-PD-2.0",
	"www.sendmail.com/pdfs/open_source/sendmail_license.pdf":                                             "Sendmail",
	"www.smlnj.org/license.html":                                                                         "SMLNJ",
	"www.sqlite.org/src/artifact/e33a4df7e32d742a?ln=4-9":                                                "blessing",
	"www.sugarcrm.com/crm/SPL":                                                                           "SugarCRM-1.1.3",
	"www.tapr.org/OHL":                                                                                   "TAPR-OHL-1.0",
	"www.tcl.tk/software/tcltk/license.html":                                                             "TCL",
	"www.tq-group.com/filedownloads/files/software-license-conditions/OriginalSSLeay/OriginalSSLeay.pdf": "SSLeay-standalone",
	"www.unicode.org/copyright.html":                                                                     "Unicode-TOU",
	"www.unicode.org/license.txt":                                                                        "Unicode-DFS-2016",
	"www.unidata.ucar.edu/software/netcdf/copyright.html":                                                "NetCDF",
	"www.users.on.net/~triforce/glidexp/COPYING.txt":                                                     "Glide",
	"www.w3.org/Consortium/Legal/2002/copyright-software-20021231.html":                                  "W3C",
	"www.w3.org/Consortium/Legal/2015/copyright-software-and-document":                                   "W3C-20150513",
	"www.w3.org/Consortium/Legal/copyright-software-19980720.html":                                       "W3C-19980720",
	"www.w3.org/copyright/software-license-2015/":                                                        "W3C-20150513",
	"www.w3.org/copyright/software-license-2023/":                                                        "W3C-20150513",
	"www.wtfpl.net/about/":                                                                               "WTFPL",
	"www.x.org/archive/current/doc/xorg-docs/License.html#Theodore_Tso":                                  "BSD-3-Clause-Tso",
	"www.xfree86.org/3.3.6/COPYRIGHT2.html#3":                                                            "X11",
	"www.xfree86.org/current/LICENSE4.html":                                                              "XFree86-1.1",
	"www.zimbra.com/legal/zimbra-public-license-1-4":                                                     "Zimbra-1.4",
	"www.zimbra.com/license/yahoo_public_license_1.0.html":                                               "YPL-1.0",
	"www.zimbra.com/license/yahoo_public_license_1.1.html":                                               "YPL-1.1",
	"www.zlib.net/zlib_license.html":                                                                     "Zlib",
}
